# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-01-13 02:35
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.db.models.manager
import django.utils.timezone
import mptt.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='AdditionalField',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True, verbose_name='Name')),
                ('field_type', models.CharField(choices=[(b'char', 'Char field'), (b'text', 'Text field'), (b'int', 'Integer field'), (b'float', 'Float field'), (b'image', 'Image field')], max_length=20, verbose_name="Field's data type")),
                ('render', models.BooleanField(default=False, verbose_name="Render field's value")),
            ],
            options={
                'ordering': ['name'],
                'verbose_name': 'Additional field',
                'verbose_name_plural': 'Additional fields',
            },
        ),
        migrations.CreateModel(
            name='Content',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=250, verbose_name='Title')),
                ('h1', models.CharField(blank=True, max_length=250, null=True, verbose_name='H1 tag')),
                ('intro', models.TextField(blank=True, null=True, verbose_name='Intro')),
                ('content', models.TextField(blank=True, null=True, verbose_name='Content')),
                ('language', models.CharField(choices=[(b'ru', b'Russian'), (b'en', b'English'), (b'fr', b'France')], default=b'ru', max_length=10, verbose_name='Language')),
                ('meta_title', models.CharField(blank=True, max_length=250, null=True, verbose_name='Meta Title')),
                ('meta_keywords', models.TextField(blank=True, null=True, verbose_name='Meta Keywords')),
                ('meta_description', models.TextField(blank=True, null=True, verbose_name='Meta Description')),
                ('published', models.BooleanField(default=False, verbose_name='Published')),
                ('pub_datetime', models.DateTimeField(default=django.utils.timezone.now, verbose_name='Created datetime')),
                ('last_modified', models.DateTimeField(auto_now=True, verbose_name='Last modified datetime')),
                ('author', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='created_contents', to=settings.AUTH_USER_MODEL, verbose_name='Author')),
                ('last_modified_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='modified_contents', to=settings.AUTH_USER_MODEL, verbose_name='Corrector')),
            ],
        ),
        migrations.CreateModel(
            name='FieldValue',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('value', models.TextField(verbose_name='Value')),
                ('additional_field', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='content.AdditionalField', verbose_name='Additional field')),
                ('content', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='content.Content', verbose_name='Content')),
            ],
            options={
                'verbose_name': "Additional field's value",
                'verbose_name_plural': "Additional field's values",
            },
        ),
        migrations.CreateModel(
            name='Menu',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('sys_name', models.CharField(max_length=255, verbose_name='System name')),
            ],
            options={
                'ordering': ['name'],
                'verbose_name': 'Menu',
                'verbose_name_plural': 'Menus',
            },
        ),
        migrations.CreateModel(
            name='Page',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=250, verbose_name='Title')),
                ('slug', models.CharField(blank=True, max_length=250, unique=True, verbose_name='Slug')),
                ('is_home', models.BooleanField(default=False, verbose_name='Is home page')),
                ('is_category', models.BooleanField(default=False, verbose_name='Is category')),
                ('miniature', models.ImageField(blank=True, null=True, upload_to=b'H:\\GITHUB\\virtenviro\\..\\media\\img\\miniature', verbose_name='Miniature')),
                ('ordering', models.IntegerField(default=999999, verbose_name='Ordering')),
                ('login_required', models.BooleanField(default=False, verbose_name='Login required')),
                ('published', models.BooleanField(default=False, verbose_name='Published')),
                ('pub_datetime', models.DateTimeField(default=django.utils.timezone.now, verbose_name='Created datetime')),
                ('last_modified', models.DateTimeField(auto_now=True, verbose_name='Last modified datetime')),
                ('lft', models.PositiveIntegerField(db_index=True, editable=False)),
                ('rght', models.PositiveIntegerField(db_index=True, editable=False)),
                ('tree_id', models.PositiveIntegerField(db_index=True, editable=False)),
                ('level', models.PositiveIntegerField(db_index=True, editable=False)),
                ('author', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='created_pages', to=settings.AUTH_USER_MODEL, verbose_name='Author')),
                ('last_modified_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='modified_pages', to=settings.AUTH_USER_MODEL, verbose_name='Corrector')),
                ('parent', mptt.fields.TreeForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='child_set', to='content.Page', verbose_name='Parent')),
            ],
            options={
                'ordering': ['ordering', '-pub_datetime', 'title'],
                'verbose_name': 'Page',
                'verbose_name_plural': 'Pages',
            },
            managers=[
                ('_default_manager', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='PageMenuRelationship',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(blank=True, max_length=255, null=True, verbose_name='Title')),
                ('url', models.URLField(blank=True, null=True)),
                ('target', models.CharField(blank=True, choices=[(b'_blank', b'_blank'), (b'_self', b'_self'), (b'_parent', b'_parent'), (b'_top', b'_top')], max_length=15, null=True, verbose_name='Target')),
                ('code', models.TextField(blank=True, null=True, verbose_name='\u041a\u043e\u0434 \u0441\u0441\u044b\u043b\u043a\u0438')),
                ('menu_item_type', models.CharField(choices=[(b'page', '\u0421\u0442\u0440\u0430\u043d\u0438\u0446\u0430'), (b'url', 'URL'), (b'code', '\u041a\u043e\u0434 \u0441\u0441\u044b\u043b\u043a\u0438')], default='page', max_length=25, verbose_name='\u0422\u0438\u043f \u044d\u043b\u0435\u043c\u0435\u043d\u0442\u0430 \u043c\u0435\u043d\u044e')),
                ('ordering', models.IntegerField(default=9999, verbose_name='Ordering')),
                ('menu', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='content.Menu')),
                ('page', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='content.Page')),
            ],
            options={
                'ordering': ['menu', 'ordering'],
                'verbose_name': 'Page Menu Relationship',
                'verbose_name_plural': 'Page Menu Relationships',
            },
        ),
        migrations.CreateModel(
            name='Snippet',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True, verbose_name='Name')),
                ('code', models.TextField(blank=True, null=True, verbose_name='Code')),
                ('render', models.BooleanField(default=False, verbose_name='Render')),
                ('template', models.CharField(blank=True, max_length=255, null=True, verbose_name='Template')),
            ],
            options={
                'ordering': ['name'],
                'verbose_name': 'Snippet',
                'verbose_name_plural': 'Snippets',
            },
        ),
        migrations.CreateModel(
            name='Tag',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tag', models.CharField(max_length=200, verbose_name='Tag')),
                ('content', models.ManyToManyField(related_name='tags', to='content.Content', verbose_name='Content')),
            ],
            options={
                'ordering': ['tag'],
                'verbose_name': 'Tag',
                'verbose_name_plural': 'Tags',
            },
        ),
        migrations.CreateModel(
            name='Template',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=255, verbose_name='Title')),
                ('filename', models.CharField(max_length=255, verbose_name='Filename')),
                ('lft', models.PositiveIntegerField(db_index=True, editable=False)),
                ('rght', models.PositiveIntegerField(db_index=True, editable=False)),
                ('tree_id', models.PositiveIntegerField(db_index=True, editable=False)),
                ('level', models.PositiveIntegerField(db_index=True, editable=False)),
                ('parent', mptt.fields.TreeForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='content.Template', verbose_name='Parent')),
            ],
            options={
                'ordering': ['title'],
                'verbose_name': 'Template',
                'verbose_name_plural': 'Templates',
            },
            managers=[
                ('_default_manager', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AddField(
            model_name='page',
            name='template',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='content.Template', verbose_name='Template'),
        ),
        migrations.AddField(
            model_name='menu',
            name='page',
            field=models.ManyToManyField(through='content.PageMenuRelationship', to='content.Page', verbose_name='Page'),
        ),
        migrations.AddField(
            model_name='content',
            name='parent',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contents', to='content.Page', verbose_name='Parent'),
        ),
        migrations.AddField(
            model_name='content',
            name='template',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='content.Template', verbose_name='Template'),
        ),
        migrations.AddField(
            model_name='additionalfield',
            name='template',
            field=models.ManyToManyField(related_name='additional_fields', to='content.Template', verbose_name='Templates'),
        ),
        migrations.AlterUniqueTogether(
            name='page',
            unique_together=set([('parent', 'slug')]),
        ),
    ]



# ~*~ coding: utf-8 ~*~
from django.conf.urls import url, include
from django.conf import settings
from django import __version__

if __version__.startswith('1.9'):
    app_name = 'vadmin'

    urlpatterns = [
        url(r'^$', 'virtenviro.admin.views.index', name='home'),
    ]

    if 'virtenviro.content' in settings.INSTALLED_APPS:
        urlpatterns += [
            url(r'^content/$', 'virtenviro.content.admin_views.content_page', name='content'),
            url(r'^content/(?P<page_id>\d+)/$', 'virtenviro.content.admin_views.content_page_edit',
                name='content_page_edit'),
            url(r'^content/add/$', 'virtenviro.content.admin_views.content_page_add', name='content_page_add'),
        ]

    if 'virtenviro.shop' in settings.INSTALLED_APPS:
        urlpatterns += [
            url(r'^shop/$', 'virtenviro.admin.views.shop', name='vadmin_shop'),
            url(r'^shop/import_yml/$', 'virtenviro.shop.views.import_yml', name='vadmin_import_yml'),
        ]
else:
    from django.conf.urls import patterns

    urlpatterns = patterns('',
                           url(r'^$', 'virtenviro.admin.views.index', name='home'), )

    if 'virtenviro.content' in settings.INSTALLED_APPS:
        urlpatterns += patterns('',
                                url(r'^content/$', 'virtenviro.content.admin_views.content_page', name='content'),
                                url(r'^content/(?P<page_id>\d+)/$', 'virtenviro.content.admin_views.content_page_edit',
                                    name='content_page_edit'),
                                url(r'^content/add/$', 'virtenviro.content.admin_views.content_page_add',
                                    name='content_page_add'),
                                )

    if 'virtenviro.shop' in settings.INSTALLED_APPS:
        urlpatterns += patterns('',
                                url(r'^shop/$', 'virtenviro.admin.views.shop', name='vadmin_shop'),
                                url(r'^shop/import_yml/$', 'virtenviro.shop.views.import_yml',
                                    name='vadmin_import_yml'),
                                )



# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2015-12-26 03:46
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='UserProfile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('birthday', models.DateField(blank=True, null=True)),
                ('language', models.CharField(choices=[(b'ru', b'Russian'), (b'en', b'English'), (b'fr', b'France')], default=b'ru', max_length=10)),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created at')),
                ('updated_at', models.DateTimeField(auto_now=True, verbose_name='Updated at')),
                ('activation_code', models.CharField(blank=True, max_length=255, null=True, verbose_name='Activation code')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]



#~*~ coding: utf-8 ~*~
from django import forms


class UserForm(forms.ModelForm):
    firstname = forms.CharField(max_length=30, required=False)
    lastname = forms.CharField(max_length=30, required=False)
    email = forms.CharField(max_length=30)
    pass1 = forms.CharField(widget=forms.PasswordInput, label="Пароль", min_length=6, max_length=30)
    pass2 = forms.CharField(widget=forms.PasswordInput, label="Пароль ещё раз")
    
    def clean_pass2(self):
        if not self.cleaned_data["pass2"] == self.cleaned_data.get("pass1",""):
            raise forms.ValidationError("Пароли не совпадают")
        return self.cleaned_data["pass2"]


class UserProfileForm(forms.ModelForm):
    weight = forms.IntegerField( min_value = 10, max_value = 200 )


# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2015-12-26 03:46
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.db.models.manager
import filebrowser.fields
import mptt.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('slug', models.CharField(blank=True, max_length=60, null=True, verbose_name='Slug')),
                ('description', models.TextField(blank=True, null=True, verbose_name='Description')),
                ('image', models.ImageField(blank=True, null=True, upload_to='H:\\GITHUB\\virtenviro\\..\\media\\img\\shop\\category', verbose_name='Image')),
                ('ordering', models.IntegerField(blank=True, default=0, null=True, verbose_name='Ordering')),
                ('view_count', models.IntegerField(blank=True, default=0, null=True, verbose_name='Count of views')),
                ('meta_title', models.CharField(blank=True, max_length=250, null=True, verbose_name='Meta Title')),
                ('meta_keywords', models.TextField(blank=True, null=True, verbose_name='Meta Keywords')),
                ('meta_description', models.TextField(blank=True, null=True, verbose_name='Meta Description')),
                ('lft', models.PositiveIntegerField(db_index=True, editable=False)),
                ('rght', models.PositiveIntegerField(db_index=True, editable=False)),
                ('tree_id', models.PositiveIntegerField(db_index=True, editable=False)),
                ('level', models.PositiveIntegerField(db_index=True, editable=False)),
                ('parent', mptt.fields.TreeForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='subcategories', to='shop.Category', verbose_name='Parent')),
            ],
            options={
                'ordering': ['name'],
                'verbose_name': 'Category',
                'verbose_name_plural': 'Categories',
            },
            managers=[
                ('_default_manager', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='Currency',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=50, verbose_name='Currency')),
                ('default', models.BooleanField(default=False, verbose_name='Is default currency')),
                ('symbol', models.CharField(blank=True, max_length=10, null=True, verbose_name='Symbol')),
                ('char_code', models.CharField(blank=True, max_length=10, null=True, verbose_name='Char code of currency')),
                ('num_code', models.IntegerField(blank=True, null=True, verbose_name='Code of currency')),
                ('nominal', models.FloatField(blank=True, null=True, verbose_name='Nominal')),
                ('value', models.FloatField(blank=True, null=True, verbose_name='Value')),
            ],
            options={
                'ordering': ['name'],
                'verbose_name': 'Currency',
                'verbose_name_plural': 'Currencies',
            },
        ),
        migrations.CreateModel(
            name='File',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('file', filebrowser.fields.FileBrowseField(blank=True, max_length=200, null=True, verbose_name=b'File')),
                ('name', models.CharField(blank=True, max_length=255, null=True, verbose_name='Name')),
            ],
        ),
        migrations.CreateModel(
            name='Image',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('image', filebrowser.fields.FileBrowseField(blank=True, max_length=200, null=True, verbose_name=b'Image')),
                ('name', models.CharField(blank=True, max_length=255, null=True, verbose_name='Name')),
                ('is_main', models.BooleanField(default=False, verbose_name='Is Main')),
            ],
            options={
                'ordering': ['image_type', 'name'],
                'verbose_name': 'Image',
                'verbose_name_plural': 'Images',
            },
        ),
        migrations.CreateModel(
            name='ImageType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
            ],
            options={
                'ordering': ['name'],
                'verbose_name': 'Images Type',
                'verbose_name_plural': 'Images Types',
            },
        ),
        migrations.CreateModel(
            name='ImageTypeCategoryRelation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('max_count', models.IntegerField(default=1, help_text='Maximum number of images by this image type in category', verbose_name='Count')),
                ('category', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='shop.Category', verbose_name='Category')),
                ('image_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='shop.ImageType', verbose_name='Image type')),
            ],
        ),
        migrations.CreateModel(
            name='Manufacturer',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True, verbose_name='Manufacturer')),
                ('description', models.TextField(blank=True, null=True, verbose_name='Description')),
                ('slug', models.CharField(blank=True, max_length=60, null=True, verbose_name='Slug')),
                ('logo', models.ImageField(blank=True, null=True, upload_to=b'H:\\GITHUB\\virtenviro\\..\\media\\img\\shop\\manufacturers', verbose_name='Logo')),
                ('country', models.CharField(blank=True, max_length=150, null=True, verbose_name='Country')),
                ('city', models.CharField(blank=True, max_length=150, null=True, verbose_name='City')),
                ('address', models.CharField(blank=True, max_length=255, null=True, verbose_name='Address')),
                ('phones', models.TextField(blank=True, null=True, verbose_name='Phones')),
            ],
            options={
                'ordering': ['name'],
                'verbose_name': 'Manufacturer',
                'verbose_name_plural': 'Manufacturers',
            },
        ),
        migrations.CreateModel(
            name='Order',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_time', models.DateTimeField(auto_now_add=True)),
                ('modified_time', models.DateTimeField(auto_now=True)),
            ],
            options={
                'ordering': ['-created_time'],
                'verbose_name': 'Order',
                'verbose_name_plural': 'Orders',
            },
        ),
        migrations.CreateModel(
            name='OrderStatus',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=60, verbose_name='Name')),
            ],
            options={
                'ordering': ['name'],
                'verbose_name': 'Order status',
                'verbose_name_plural': 'Order statuses',
            },
        ),
        migrations.CreateModel(
            name='Product',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('slug', models.CharField(blank=True, max_length=60, null=True, verbose_name='Slug')),
                ('articul', models.CharField(blank=True, max_length=200, null=True, verbose_name='Articul')),
                ('description', models.TextField(blank=True, null=True, verbose_name='Description')),
                ('price', models.FloatField(default=0.0, verbose_name='Price')),
                ('discount', models.FloatField(default=0, verbose_name='Discount')),
                ('ordering', models.IntegerField(blank=True, default=0, null=True, verbose_name='Ordering')),
                ('view_count', models.IntegerField(blank=True, default=0, null=True, verbose_name='Count of views')),
                ('meta_title', models.CharField(blank=True, max_length=250, null=True, verbose_name='Meta Title')),
                ('meta_keywords', models.TextField(blank=True, null=True, verbose_name='Meta Keywords')),
                ('meta_description', models.TextField(blank=True, null=True, verbose_name='Meta Description')),
                ('category', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='children', to='shop.Category', verbose_name='Category')),
                ('manufacturer', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='shop.Manufacturer', verbose_name='Manufacturer')),
                ('subcategory', models.ManyToManyField(blank=True, related_name='products', to='shop.Category', verbose_name='Subcategory')),
            ],
            options={
                'ordering': ['ordering', 'name'],
                'verbose_name': 'Product',
                'verbose_name_plural': 'Products',
            },
        ),
        migrations.CreateModel(
            name='ProductOrderRelation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('count', models.IntegerField(default=1, verbose_name='Count')),
                ('order', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='shop.Order', verbose_name='Order')),
                ('product', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='shop.Product', verbose_name='Product')),
            ],
        ),
        migrations.CreateModel(
            name='Property',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('value', models.TextField(verbose_name='Value')),
                ('product', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='shop.Product', verbose_name='Product')),
            ],
            options={
                'ordering': ['property_type__name', 'value'],
                'verbose_name': 'Property',
                'verbose_name_plural': 'Properties',
            },
        ),
        migrations.CreateModel(
            name='PropertySlug',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('value', models.TextField(verbose_name='Value')),
                ('slug', models.CharField(max_length=60, verbose_name='Slug')),
            ],
            options={
                'ordering': ['value'],
                'verbose_name': 'Property slug',
                'verbose_name_plural': 'Property slugs',
            },
        ),
        migrations.CreateModel(
            name='PropertyType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('data_type', models.IntegerField(choices=[(-1, 'Integer'), (-2, 'Float'), (-3, 'String'), (-4, 'Text'), (-5, 'Boolean'), (-6, 'Html')], default=-1, verbose_name='Data type')),
            ],
            options={
                'ordering': ['name'],
                'verbose_name': 'Properties type',
                'verbose_name_plural': 'Properties Types',
            },
        ),
        migrations.CreateModel(
            name='PropertyTypeCategoryRelation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('max_count', models.IntegerField(default=1, help_text='Maximum number of properties by this property type in category', verbose_name='Count')),
                ('slug', models.CharField(blank=True, max_length=60, null=True, verbose_name='Slug')),
                ('category', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='shop.Category', verbose_name='Category')),
                ('property_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='shop.PropertyType', verbose_name='Property Type')),
            ],
        ),
        migrations.CreateModel(
            name='Seller',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('description', models.TextField(blank=True, null=True, verbose_name='Description')),
                ('slug', models.CharField(max_length=60, verbose_name='Slug')),
                ('image', models.ImageField(blank=True, null=True, upload_to=b'H:\\GITHUB\\virtenviro\\..\\media\\img\\shop\\sellers', verbose_name='Image')),
                ('address', models.CharField(blank=True, max_length=255, null=True, verbose_name='Address')),
                ('city', models.CharField(blank=True, max_length=255, null=True, verbose_name='City')),
                ('country', models.CharField(blank=True, max_length=255, null=True, verbose_name='Country')),
                ('postal_zip', models.CharField(blank=True, max_length=255, null=True, verbose_name='ZIP')),
                ('site', models.URLField(blank=True, null=True, verbose_name='Site')),
                ('email', models.EmailField(blank=True, max_length=254, null=True, verbose_name='Email')),
                ('phones', models.TextField(blank=True, null=True, verbose_name='Phones')),
                ('itn', models.CharField(blank=True, max_length=255, null=True, verbose_name='Individual Taxpayer Number')),
                ('ordering', models.IntegerField(default=999, verbose_name='Ordering')),
                ('map_code', models.TextField(blank=True, null=True, verbose_name="Map's code")),
            ],
            options={
                'ordering': ['ordering', 'name'],
                'verbose_name': 'Seller',
                'verbose_name_plural': 'Sellers',
            },
        ),
        migrations.AddField(
            model_name='propertytype',
            name='category',
            field=models.ManyToManyField(through='shop.PropertyTypeCategoryRelation', to='shop.Category'),
        ),
        migrations.AddField(
            model_name='propertyslug',
            name='property_type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='shop.PropertyType', verbose_name='Propert type'),
        ),
        migrations.AddField(
            model_name='property',
            name='property_type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='shop.PropertyType'),
        ),
        migrations.AddField(
            model_name='order',
            name='product',
            field=models.ManyToManyField(related_name='production', through='shop.ProductOrderRelation', to='shop.Product', verbose_name='Product'),
        ),
        migrations.AddField(
            model_name='order',
            name='status',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='shop.OrderStatus', verbose_name='Status'),
        ),
        migrations.AddField(
            model_name='order',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='User'),
        ),
        migrations.AddField(
            model_name='imagetype',
            name='category',
            field=models.ManyToManyField(through='shop.ImageTypeCategoryRelation', to='shop.Category', verbose_name='Production Type'),
        ),
        migrations.AddField(
            model_name='image',
            name='image_type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='shop.ImageType', verbose_name='Image Type'),
        ),
        migrations.AddField(
            model_name='image',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='shop.Product', verbose_name='Product'),
        ),
        migrations.AddField(
            model_name='file',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='shop.Product', verbose_name='Product'),
        ),
    ]



# ~*~ coding: utf-8 ~*~
__author__ = 'Kamo Petrosyan'
from django import template
from datetime import datetime
#from django.template import loader, Context
#from django.db import  models
#from virtenviro.content.models import Snippet, Page, AdditionalField
#from virtenviro.shop.models import *
#from virtenviro.utils import *

register = template.Library()


@register.filter
def base64(value):
    return value.encode('base64', 'strict')


class Base64Node(template.Node):
    def __init__(self, nodelist):
        self.nodelist = nodelist

    def render(self, context):
        output = self.nodelist.render(context)
        return output.encode('utf-8').encode('base64', 'strict').strip().replace('\n', '')


@register.tag
def base64_block(parser, token):
    nodelist = parser.parse(('endbase64_block',))
    parser.delete_first_token()
    return Base64Node(nodelist)


@register.filter
def get_dict_item(d, key_name):
    return d[key_name]


@register.filter
def now(dformat='%d.%m.%Y %H:%M:%s'):
    return datetime.now().strftime(format=dformat)




from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.contrib.auth.models import User
import datetime
from django.conf import settings
from pytils.translit import slugify
from django.utils import timezone


def set_slug(model, src, length=60):
    slug = slugify(src)[0:length]
    try:
        obj = model.objects.get(slug=slug)
        slug = set_slug(model, slug, length)
    except model.DoesNotExist:
        return slug


class PostManager(models.Manager):
    def last_news(self, category=None, count=None):
        if count is None:
            try:
                count = settings.LAST_NEWS_COUNT
            except Exception:
                count = 10
        posts = self.filter(published=True).order_by('-pub_datetime')[0:count]
        if not category is None:
            posts = posts.filter(category=category)
        return posts

    def published_news(self, count=None):
        news = self.filter(published=True)
        if not count is None:
            news = news[0:count]
        return news


class Category(models.Model):
    title = models.CharField(max_length=255, verbose_name=_('Title'))
    slug = models.CharField(max_length=60, verbose_name=_('Slug'), blank=True, null=False)
    description = models.TextField(verbose_name=_('Description'), null=True, blank=True)

    meta_title = models.CharField(max_length=255, verbose_name=_('Meta title'), null=True, blank=True)
    meta_keywords = models.CharField(max_length=255, verbose_name=_('Meta keywords'), null=True, blank=True)
    meta_description = models.CharField(max_length=255, verbose_name=_('Meta description'), null=True, blank=True)

    def clean(self):
        if not self.slug:
            self.slug = set_slug(Category, self.title, length=60)

    def __unicode__(self):
        return self.title

    class Meta:
        ordering = ['title']
        verbose_name = _('Category')
        verbose_name_plural = _('Categories')


class Post(models.Model):
    title = models.CharField(max_length=255, verbose_name=_('Title'))
    category = models.ForeignKey(Category, verbose_name=_('Category'), null=True, blank=True)
    slug = models.CharField(max_length=60, unique=True, verbose_name=_('Slug'), null=True, blank=True)

    # CONTENT FIELDS
    intro = models.TextField(verbose_name=_('Intro'), null=True, blank=True)
    content = models.TextField(verbose_name=_('Content'))

    origin = models.URLField(null=True, blank=True, verbose_name=_('Origin\'s url address'))
    author = models.ForeignKey(User, null=True, blank=True, verbose_name=_('Author'))

    # SERVICE FIELDS
    published = models.BooleanField(default=False, verbose_name=_('Published'))
    pub_datetime = models.DateTimeField(default=timezone.now, verbose_name=_('Created datetime'))
    last_modified = models.DateTimeField(auto_now=True, verbose_name=_('Last modified datetime'))

    # META FIELDS
    meta_title = models.CharField(max_length=255, verbose_name=_('Meta title'), null=True, blank=True)
    meta_keywords = models.CharField(max_length=255, verbose_name=_('Meta keywords'), null=True, blank=True)
    meta_description = models.CharField(max_length=255, verbose_name=_('Meta description'), null=True, blank=True)

    objects = PostManager()
    
    def __unicode__(self):
        return '%s [ %s ]' % (self.title, self.created)
    
    def clean(self):
        if not self.slug:
            self.slug = set_slug(Post, self.title, length=60)

    class Meta:
        ordering = ('-pub_datetime', 'title')
        verbose_name = _('News post')
        verbose_name_plural = _('News posts')
                              



# ~*~ coding: utf-8 ~*~
__author__ = 'Kamo Petrosyan'
from django.core.management.base import BaseCommand, CommandError
from lxml import etree

from virtenviro.content.models import Page, Template, Content, Tag


class Command(BaseCommand):
    args = '<xml_file group_template_id page_template_id>'
    help = 'Imports xml file as pages in content application'

    def handle(self, *args, **options):
        if len(args) < 3:
            raise CommandError('Command import_content takes 3 arguments. {} given'.format(len(args)))
        parser = etree.XMLParser(remove_blank_text=True)
        try:
            tree = etree.parse(args[0], parser)
        except IOError:
            raise CommandError('Error reading file \'{0}\': failed to load external entity "{0}"'.format(args[0]))

        try:
            group_template = Template.objects.get(pk=int(args[1]))
        except Template.DoesNotExist:
            raise CommandError('Template {} Does not exist'.format(args[1]))
        except ValueError:
            raise CommandError('Argument 1 is not integer value ')
        try:
            page_template = Template.objects.get(pk=int(args[2]))
        except Template.DoesNotExist:
            raise CommandError('Template {} Does not exist'.format(args[2]))
        except ValueError:
            raise CommandError('Argument 2 is not integer value ')

        for page_xml in tree.findall('.//page'):
            title = page_xml.find('title').text
            if not title:
                continue
            slug = page_xml.find('slug').text
            try:
                page, created = Page.objects.get_or_create(title=title, slug=slug, is_home=False, template=page_template, published=True)
            except:
                pass

        for page_xml in tree.iterfind('.//page'):
            title = page_xml.find('title').text
            slug = page_xml.find('slug').text
            try:
                page = Page.objects.get(title=title, slug=slug)
            except:
                continue
            try:
                if not title:
                    continue
                content, created = Content.objects.get_or_create(title=title, language='ru',  parent=page,
                                                                 defaults={
                                                                     'published': True,
                                                                     'content': page_xml.find('content').text})
                page_parent_title = page_xml.find('parent').text
                if page_parent_title and not page_parent_title == title:
                    page.parent = Page.objects.filter(title=page_parent_title)[0]
                    page.save()
                    if not page.parent.is_category:
                        pp = page.parent
                        pp.is_category = True
                        pp.template = group_template
                        pp.save()
                tags = page_xml.find('tags')
                for tag_xml in tags.findall('tag'):
                    tag = Tag.objects.get_or_create(tag=tag_xml.text)
                    if not tag in content.tags:
                        content.tags.add(tag)
            except:
                self.stdout.write(u'{} {}'.format(title, slug))




from django import template
from django.template.loader import render_to_string

register = template.Library()

@register.simple_tag
def adsense_p(content, pnum, ad_template, start_default=False, end_default=False):
    # Render our adsense code placed in html file
    ad_code = render_to_string("adsense/%s.html"%ad_template)

    # Break down content into paragraphs
    paragraphs = content.split('</p>')

    # Check if paragraph we want to post after exists
    if pnum < len(paragraphs):
        # Append our code before the following paragraph
        paragraphs[pnum] = ad_code + paragraphs[pnum]
        # Assemble our text back with injected adsense code
        content = '</p>'.join(paragraphs)
    elif start_default:
        content = ad_code + '</p>'.join(paragraphs)
    elif end_default:
        content = '</p>'.join(paragraphs) + ad_code
    else:
        content = '</p>'.join(paragraphs)
    return content



#~*~ coding: utf-8 ~*~
from django.conf.urls import patterns, include, url

urlpatterns = patterns('',
    url(r'^import_simple_xml/$', 'virtenviro.shop.views.import_simple_xml', name='import_simple_xml'),
)


#~*~ coding: utf-8 ~*~
from django.conf.urls import *

from virtenviro.registration.views import signup


urlpatterns = patterns('',
    url( r'^signup/$', signup ),
    url( r'^login/$', 'django.contrib.auth.views.login', { "template_name": "virtenviro/accounts/login.html"} ),
    url( r'^logout/$', 'django.contrib.auth.views.logout_then_login', name='logout' ),
)


# ~*~ coding: utf-8 ~*~
__author__ = 'Kamo Petrosyan'
import os
import codecs
from django.conf import settings

MEDIA_ROOT = getattr(settings, 'MEDIA_ROOT', getattr(settings, 'STATIC_ROOT'))


class Logger:
    def __init__(self, filename, src):
        file = codecs.open(os.path.join(MEDIA_ROOT, 'logs', filename), 'a', 'utf-8')
        file.write(src+'\n')
        file.close()



from django.test import TestCase

class SimpleTest(TestCase):
    def test_basic_addition(self):
        """
        Tests that 1 + 1 always equals 2.
        """
        self.failUnlessEqual(1 + 1, 2)

__test__ = {"doctest": """
Another way to test that 1 + 1 is equal to 2.

>>> 1 + 1 == 2
True
"""}




from required_settings import *

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
import os
BASE_DIR = os.path.dirname(os.path.dirname(__file__))

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = 'lvp778_p-fhyu_%58(64nr3ein#)geca^c_p-vxt15!w%bjw3m'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

TEMPLATE_DEBUG = True

ALLOWED_HOSTS = []

ROOT_URLCONF = 'virtenviro.urls'

WSGI_APPLICATION = 'virtenviro.wsgi.application'

# Database
# https://docs.djangoproject.com/en/1.7/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
    }
}

# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/1.7/howto/static-files/
STATIC_ROOT = os.path.join(BASE_DIR, 'virtenviro/static')
STATIC_URL = '/static/'

MEDIA_ROOT = os.path.join(BASE_DIR, '..', 'media')
MEDIA_URL = '/media/'

TEMPLATE_DIRS = (
    os.path.join(BASE_DIR, 'templates'),
)

CKEDITOR = True
FILEBROWSER_MEDIA_ROOT = MEDIA_ROOT
FILEBROWSER_MEDIA_URL = MEDIA_URL
FILEBROWSER_DIRECTORY = ''
FILEBROWSER_URL_FILEBROWSER_MEDIA = STATIC_URL + "filebrowser/"
FILEBROWSER_PATH_FILEBROWSER_MEDIA = os.path.join(STATIC_ROOT, 'filebrowser/')
FILEBROWSER_EXTENSIONS = {
    'Image': ['.jpg', '.jpeg', '.gif', '.png', '.tif', '.tiff'],
    'Document': ['.pdf', '.doc', '.docx', '.rtf', '.txt', '.xls', '.xlsx', '.csv'],
    'Video': ['.mov', '.wmv', '.mpeg', '.mpg', '.avi', '.rm'],
    'Audio': ['.mp3', '.mp4', '.wav', '.aiff', '.midi', '.m4p']
}

FILEBROWSER_SELECT_FORMATS = {
    'file': ['Folder', 'Image', 'Document', 'Video', 'Audio'],
    'image': ['Image'],
    'document': ['Document'],
    'media': ['Video','Audio'],
}
FILEBROWSER_VERSIONS = {
    'admin_thumbnail': {'verbose_name': 'Admin Thumbnail', 'width': 60, 'height': 60, 'opts': 'crop'},
    'thumbnail': {'verbose_name': 'Thumbnail (1 col)', 'width': 60, 'height': 60, 'opts': 'crop'},
    'small': {'verbose_name': 'Small (2 col)', 'width': 140, 'height': '', 'opts': ''},
    'medium': {'verbose_name': 'Medium (4col )', 'width': 300, 'height': '', 'opts': ''},
    'big': {'verbose_name': 'Big (6 col)', 'width': 460, 'height': '', 'opts': ''},
    'large': {'verbose_name': 'Large (8 col)', 'width': 680, 'height': '', 'opts': ''},
}

LANGUAGES += (
    ('en', 'English'),
    ('fr', 'France'),
)



# ~*~ coding: utf-8 ~*~
__author__ = 'Kamo Petrosyan'
from django import template
from django.db.models import Q
from virtenviro.content.models import Snippet, Page, AdditionalField, Menu
from django.template import loader, Context
from virtenviro.utils import *

register = template.Library()


@register.assignment_tag
def additional_field(page, field_name):
    try:
        additional_field = AdditionalField.objects.get(name=field_name)
        field = page.fieldvalue_set.filter(additional_field=additional_field)
        if field.count() > 0:
            return field[0]
    except AdditionalField.DoesNotExist:
        return None


@register.simple_tag(takes_context=True)
def render_snippet(context, snippet_name):
    try:
        snippet = Snippet.objects.get(name=snippet_name)
    except Snippet.DoesNotExist:
        snippet = None
    if snippet.render:
        t = loader.get_template_from_string(snippet.code)
        res = t.render(Context(context))
        return res

    return snippet.code


@register.simple_tag(takes_context=True)
def render_content(context, content):
    t = loader.get_template_from_string(content)
    return t.render(Context(context))


@register.simple_tag(takes_context=True)
def render_field(context, page, field_name):
    try:
        additional_field = AdditionalField.objects.get(name=field_name)
    except AdditionalField.DoesNotExist:
        return ''
    field = page.fieldvalue_set.filter(additional_field=additional_field)
    if additional_field.render:
        t = loader.get_template_from_string(field.value)
        return t.render(Context(context))
    else:
        return field.value


@register.assignment_tag(takes_context=True)
def get_pages(context, *args, **kwargs):
    parent_id = kwargs.get('parent', 0)
    if parent_id == 0:
        queryset = Page.objects.filter(parent__isnull=True)
    else:
        if isinstance(parent_id, int):
            try:
                parent_node = Page.objects.get(id=parent_id)
            except Page.DoesNotExist:
                return None
        elif isinstance(parent_id, str) or isinstance(parent_id, unicode):
            try:
                parent_node = Page.objects.get(slug=parent_id)
            except Page.DoesNotExist:
                return None
        level = kwargs.get('level', 1) + 1

        queryset = Page.objects.filter(
            level__lte=level,
            tree_id=parent_node.tree_id,
            lft__gte=parent_node.lft,
            rght__lte=parent_node.rght)
        if not kwargs.get('include_parents', False):
            queryset = queryset.exclude(level__lte=parent_node.level)
        if kwargs.get('author', False):
            queryset = queryset.filter(author=kwargs['author'])
    queryset = queryset.order_by(kwargs.get('order', 'id'))
    if context['request'].GET.has_key('page'):
        rpage = context['request'].GET['page']
    else:
        rpage = 1
    if kwargs.get('limit', False):
        queryset = paginate(queryset, rpage, int(kwargs['limit']))
    return queryset


@register.assignment_tag(takes_context=True)
def get_content_ml(context, page, lang):
    content = page.get_content(language=lang)
    return content


@register.assignment_tag
def leaf_pages(root=None, root_id=None, count=0, rnd=False):
    if root is None:
        if root_id is None:
            return []
        else:
            try:
                root = Page.objects.get(pk=root_id)
            except Page.DoesNotExist:
                return []
    nodes = []
    m_nodes = root.get_descendants(include_self=False).order_by('-pub_datetime', '-pk')

    if rnd:
        m_nodes = m_nodes.order_by('?')
    if count == 0:
        count = m_nodes.count()
    for m_node in m_nodes:
        if m_node.is_leaf_node():
            nodes.append(m_node)
        count -= 1
        if count == 0:
            break
    return nodes

@register.assignment_tag
def page_breadcrumb(page):
    breadcrumb = [page]

    while page.parent:
        page = page.parent
        breadcrumb.append(page)
    breadcrumb.reverse()
    return breadcrumb


@register.assignment_tag
def get_page_by_id(page_id):
    try:
        return Page.objects.get(pk=page_id)
    except Page.DoesNotExist:
        return None


@register.assignment_tag
def get_menu(sys_name):
    try:
        menu = Menu.objects.get(sys_name=sys_name)
    except Menu.DoesNotExist:
        return None
    return menu.pagemenurelationship_set.all().order_by('ordering')



# ~*~ coding: utf-8 ~*~
from django.shortcuts import render, redirect
from django.http import Http404
from django.utils.http import urlquote
from django.conf import settings

from virtenviro.content.models import *


def home(request):
    try:
        page = Page.objects.get(is_home=True)
    except Page.DoesNotExist:
        raise Http404
    return render(request, page.template.filename, {'page': page}, )


def view(request):
    """

    :param request: request
    :return: render
    """
    try:
        path = request.path.lstrip('page')
        path = path.strip('/').split('/')
        page = Page.objects.get(slug=path[-1], is_home=False) or Page.objects.get(slug=path[-1], parent__slug=path[-2],
                                                                                  is_home=False)
        if page.login_required and not request.user.is_authenticated():
            return redirect(settings.LOGIN_URL, next=urlquote(request.get_full_path()))
    except Page.DoesNotExist:
        raise Http404
    return render(request, page.template.filename, {'page': page, 'request': request}, )


def show_as_blog(request, parent):
    """

    :param request:
    :param parent: Page object - category of the blog
    :return: render
    """
    pass


def show_as_simple_page(request, page):
    """

    :param request:
    :param parent: Page object - category of the blog
    :return: render
    """
    pass


def app(request, page, app):
    """

    :param request:
    :param page: Page
    :param app: application
    :return:
    """
    pass


# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('shop', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='category',
            managers=[
            ],
        ),
        migrations.AlterField(
            model_name='category',
            name='image',
            field=models.ImageField(upload_to='/srv/www/virtenviro/../media/img/shop/category', null=True, verbose_name='Image', blank=True),
        ),
        migrations.AlterField(
            model_name='manufacturer',
            name='logo',
            field=models.ImageField(upload_to=b'/srv/www/virtenviro/../media/img/shop/manufacturers', null=True, verbose_name='Logo', blank=True),
        ),
        migrations.AlterField(
            model_name='seller',
            name='image',
            field=models.ImageField(upload_to=b'/srv/www/virtenviro/../media/img/shop/sellers', null=True, verbose_name='Image', blank=True),
        ),
    ]



#~*~ coding: utf-8 ~*~
from django.db import models
from django.contrib.sites.models import Site
from django.contrib.auth.models import User
from django.conf import settings
from django.core.mail import EmailMultiAlternatives
from django.template.loader import render_to_string
from django.utils.translation import ugettext_lazy as _
from virtenviro.utils import id_generator


class UserProfile(models.Model):
    user = models.ForeignKey(User, null=True, blank=True)
    birthday = models.DateField(blank=True, null=True)
    language = models.CharField(max_length=10, choices=settings.LANGUAGES, default='ru')
    created_at = models.DateTimeField(auto_now_add=True, verbose_name=_('Created at'))
    updated_at = models.DateTimeField(auto_now=True, verbose_name=_('Updated at'))
    activation_code = models.CharField(max_length=255, verbose_name=_('Activation code'), null=True, blank=True)

    def clean(self):
        if not self.activation_code:
            self.activation_code = id_generator(size=20)

    def generate_activation_code(self):
        self.activation_code = id_generator(size=20)
        self.save()

    def repair_password(self):
        self.generate_activation_code()
        self.send_mail(
            template='repair',
            subject=u'Восстановление доступа к сайту {}'.format(Site.objects.get_current()))

    def send_activation_code(self):
        self.send_mail(
            template='registration',
            subject=u'Активация доступа к сайту {}'.format(Site.objects.get_current()))

    def send_mail(self, template, subject):
        from_email = getattr(settings, 'FROM_EMAIL', None)
        if from_email is None:
            return False

        context = {'profile': self, 'site': Site.objects.get_current()}
        text_content = render_to_string('accounts/email/{}.txt'.format(template), context)
        html_content = render_to_string('accounts/email/{}.html'.format(template), context)
        msg = EmailMultiAlternatives(subject, text_content, from_email, [self.user.email])
        msg.attach_alternative(html_content, "text/html")
        msg.send()
        return True

    def __unicode__(self):
        return self.user.username


#def user_post_save(sender, instance, **kwargs):
#    (profile, new) = UserProfile.objects.get_or_create(user=instance)

#models.signals.post_save.connect(user_post_save, sender=User)



# ~*~ coding: utf-8 ~*~
__author__ = 'Kamo Petrosyan'

"""
Django settings for virtenviro project.

For more information on this file, see
https://docs.djangoproject.com/en/1.7/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/1.7/ref/settings/
"""
# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/1.7/howto/deployment/checklist/
# Application definition

# Change SITE_ID in your settings.py
SITE_ID = 1

INSTALLED_APPS = (
    'mptt',
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.sites',
    'filebrowser',

    'datetimewidget',

    'virtenviro',
    'virtenviro.content',
    'virtenviro.news',
    'virtenviro.shop',
    'virtenviro.registration',
)

MIDDLEWARE_CLASSES = (
    'django.contrib.sessions.middleware.SessionMiddleware',
    #'django.middleware.cache.UpdateCacheMiddleware',
    'django.middleware.common.CommonMiddleware',
    #'django.middleware.cache.FetchFromCacheMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'django.middleware.locale.LocaleMiddleware',
    #'django.middleware.cache.CacheMiddleware',
)

TEMPLATE_CONTEXT_PROCESSORS = [
    "django.contrib.auth.context_processors.auth",
    "django.template.context_processors.debug",
    "django.template.context_processors.i18n",
    "django.template.context_processors.media",
    "django.template.context_processors.static",
    "django.template.context_processors.tz",
    "django.contrib.messages.context_processors.messages",
    "virtenviro.virtenviro_context_processors.virtenviro_context_processor",
]

#CACHE_BACKEND = 'file:///tmp/django_cache'

# Internationalization
# https://docs.djangoproject.com/en/1.7/topics/i18n/

LANGUAGE_CODE = 'ru'
LANGUAGES = (
    ('ru', 'Russian'),
)

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True

DEFAULT_ORDER_STATUS = u'Не подтвержденная'


# ~*~ coding: utf-8 ~*~
from django import forms
from datetimewidget.widgets import DateTimeWidget
from django.utils.translation import ugettext_lazy as _
from django.forms import formset_factory
from django.forms.models import modelformset_factory, inlineformset_factory
from virtenviro.content.models import *

__author__ = 'Kamo Petrosyan'


class PagesAdminForm(forms.ModelForm):

    def __init__(self, *args, **kwargs):
        super(PagesAdminForm, self).__init__(*args, **kwargs)
        self.fields['parent'].queryset = Page.objects.filter(is_category=True)

    class Meta:
        model = Page
        exclude = ['last_modified']
        widgets = {
            'title': forms.TextInput(attrs={'placeholder': _('Title'), 'class': "form-control"}),
            'slug': forms.TextInput(attrs={'placeholder': _('Slug'), 'class': "form-control"}),
            'template': forms.Select(attrs={'class': "form-control"}),
            'parent': forms.Select(attrs={'class': "form-control"}),
            'ordering': forms.NumberInput(attrs={'class': "form-control", 'min': 0}),
            'pub_datetime': DateTimeWidget(attrs={'id': "id_pub_datetime"}, usel10n=True, bootstrap_version=3),
            'last_modified_by': forms.Select(attrs={'disabled': 'disabled', 'class': 'form-control disabled'})
        }

    def clean_parent(self):
        parent = self.cleaned_data.get('parent')

        if not parent:
            parent = None

        return parent


class ContentAdminForm(forms.ModelForm):
    class Meta:
        model = Content
        widgets = {
            'title': forms.TextInput(attrs={'placeholder': _('Title'), 'class': "form-control"}),
            'h1': forms.TextInput(attrs={'placeholder': _('H1'), 'class': "form-control"}),
            'intro': forms.Textarea(attrs={'placeholder': _('Intro text'), 'class': 'form-control', 'rows': 4}),
            'content': forms.Textarea(attrs={'placeholder': _('Intro text'), 'class': 'ckeditor'}),
            'template': forms.Select(attrs={'class': "form-control"}),
            'language': forms.Select(attrs={'class': "form-control disabled"}),
            'meta_title': forms.TextInput(attrs={'placeholder': _('Meta title'), 'class': "form-control"}),
            'meta_keywords': forms.Textarea(attrs={'placeholder': _('Meta keywords'), 'class': 'form-control', 'rows': 2}),
            'meta_description': forms.Textarea(attrs={'placeholder': _('Meta description'), 'class': 'form-control', 'rows': 2}),
            'author': forms.Select(attrs={'class': 'form-control'}),
            'pub_datetime': DateTimeWidget(attrs={'class': 'form-control'}, usel10n=True, bootstrap_version=3),
            'last_modified_by': forms.Select(attrs={'disabled': 'disabled', 'class': 'form-control disabled'})
        }
        exclude = ['parent']

    class Media:
        try:
            if settings.CKEDITOR:
                js = (
                    '/static/ckeditor/ckeditor.js',
                    '/static/filebrowser/js/FB_CKEditor.js',
                    '/static/js/ckeditor.js',
                )
                css = {'all': ('/static/css/ckeditor.css',), }
        except AttributeError:
            pass


ContentAdminFormset = inlineformset_factory(
        Page,
        Content,
        form=ContentAdminForm,
        extra=len(settings.LANGUAGES),
        exclude=['last_modified'])



#~*~ coding: utf-8 ~*~
from django.contrib import admin
from django.forms import CheckboxSelectMultiple
from django import forms
from django.conf import settings
from virtenviro.content.models import *


class TemplateAdmin(admin.ModelAdmin):
    search_fields = ['title', 'filename']


class ContentAdminForm(forms.ModelForm):

    def __init__(self, *args, **kwargs):
        super(ContentAdminForm, self).__init__(*args, **kwargs)
        self.fields['content'].widget.attrs['class'] = 'ckeditor'

    class Meta:
        model = Content
        fields = [
            'title',
            'h1',
            'intro',
            'content',
            'template',
            'parent',
            'language',

            'meta_title',
            'meta_keywords',
            'meta_description',

            'published',
            'pub_datetime',
            #'last_modified',

            'author',
            # 'last_modified_by',
        ]

        def clean_author(self):
            if not self.cleaned_data['author']:
                return User()
            return self.cleaned_data['author']


class PageAdminForm(forms.ModelForm):

    class Meta:
        model = Page
        fields = [
            'title',
            'slug',
            'is_category',
            'is_home',
            'template',
            'parent',
            'published',
            'pub_datetime',
            'author',
            # 'last_modified_by',
            'login_required'
        ]

        def clean_author(self):
            if not self.cleaned_data['author']:
                return User()
            return self.cleaned_data['author']


class ContentTabularInline(admin.StackedInline):
    model = Content
    form = ContentAdminForm
    extra = 1


class MenuTabularInline(admin.StackedInline):
    model = PageMenuRelationship
    #form = MenuAdminForm
    extra = 1


class PageAdmin(admin.ModelAdmin):
    list_display = ('title', 'parent')
    formfield_overrides = {
        models.ManyToManyField: {'widget': CheckboxSelectMultiple},
    }
    search_fields = ['title', ]

    form = PageAdminForm
    inlines = [
        ContentTabularInline,
        MenuTabularInline,
    ]

    def save_model(self, request, obj, form, change):
        if not obj.author:
            obj.author = request.user
        obj.last_modified_by = request.user
        obj.save()

    def formfield_for_foreignkey(self, db_field, request, **kwargs):
        if db_field.name == 'author':
            kwargs['initial'] = request.user.id

        if db_field.name == 'last_modified_by':
            kwargs['initial'] = request.user.id
        if db_field.name == 'parent':
            kwargs["queryset"] = Page.objects.filter(is_category=True)
        return super(PageAdmin, self).formfield_for_foreignkey(
            db_field, request, **kwargs
        )

    class Media:
        try:
            if settings.CKEDITOR:
                js = (
                    '/static/ckeditor/ckeditor.js',
                    '/static/filebrowser/js/FB_CKEditor.js',
                    '/static/js/ckeditor.js',
                )
                css = {'all': ('/static/css/ckeditor.css',), }
        except AttributeError:
            pass


class TagInline(admin.StackedInline):
    model = Tag.content.through
    extra = 3


class ContentAdmin(admin.ModelAdmin):
    list_display = ('title', 'parent', 'language')
    #list_editable = ('parent',)
    list_filter = ('language',)
    formfield_overrides = {
        models.ManyToManyField: {'widget': CheckboxSelectMultiple},
    }
    search_fields = ['title', ]
    inlines = [TagInline,]

    form = ContentAdminForm

    def save_model(self, request, obj, form, change):
        if not obj.author:
            obj.author = request.user
        obj.last_modified_by = request.user
        obj.save()

    def formfield_for_foreignkey(self, db_field, request, **kwargs):
        if db_field.name == 'author':
            kwargs['initial'] = request.user.id

        if db_field.name == 'last_modified_by':
            kwargs['initial'] = request.user.id
        return super(ContentAdmin, self).formfield_for_foreignkey(
            db_field, request, **kwargs
        )

    class Media:
        try:
            if settings.CKEDITOR:
                js = (
                    '/static/ckeditor/ckeditor.js',
                    '/static/filebrowser/js/FB_CKEditor.js',
                    '/static/js/ckeditor.js',
                )
                css = {'all': ('/static/css/ckeditor.css',), }
        except AttributeError:
            pass


class MenuAdmin(admin.ModelAdmin):
    inlines = [
        MenuTabularInline,
    ]


class PageMenuRelationshipAdmin(admin.ModelAdmin):
    list_display = ('pk', 'page', 'title', 'url', 'target', 'code', 'menu_item_type', 'menu', 'ordering')
    list_editable = ('title', 'url', 'target', 'code', 'menu_item_type', 'menu', 'ordering')
    list_filter = ('menu',)

admin.site.register(Page, PageAdmin)
admin.site.register(Content, ContentAdmin)
admin.site.register(Template, TemplateAdmin)
admin.site.register(AdditionalField)
admin.site.register(FieldValue)
admin.site.register(Snippet)
admin.site.register(Tag)
admin.site.register(Menu, MenuAdmin)
admin.site.register(PageMenuRelationship, PageMenuRelationshipAdmin)


# ~*~ coding: utf-8 ~*~
__author__ = 'Kamo Petrosyan'


class Offer:
    """
    url
    URL страницы товара. Максимальная длина URL — 512 символов.
    Необязательный элемент для магазинов-салонов.

    price
    Цена, по которой данный товар можно приобрести. Цена товарного предложения округляется, формат, в котором она отображается, зависит от настроек пользователя.
    Обязательный элемент.

    oldprice
    Старая цена на товар, которая обязательно должна быть выше новой цены (<price>). Параметр <oldprice> необходим для автоматического расчета скидки на товар.
    Необязательный элемент.

    currencyId
    Идентификатор валюты товара (RUR, USD, UAH, KZT). Для корректного отображения цены в национальной валюте необходимо использовать идентификатор (например, UAH) с соответствующим значением цены.
    Обязательный элемент.

    categoryId
    Идентификатор категории товара, присвоенный магазином (целое число не более 18 знаков). Товарное предложение может принадлежать только одной категории.
    Обязательный элемент. Элемент <offer> может содержать только один элемент <categoryId>.

    market_category
    Категория товара, в которой он должен быть размещен на Яндекс.Маркете. Допустимо указывать названия категорий только из товарного дерева категорий Яндекс.Маркета.
    Необязательный элемент.
    Примечание. Скачать дерево категорий Яндекс.Маркета в формате XLS.

    picture
    Ссылка на картинку соответствующего товарного предложения. Недопустимо давать ссылку на «заглушку», т. е. на страницу, где написано «картинка отсутствует», или на логотип магазина. Максимальная длина URL — 512 символов.
    Необязательный элемент.

    store
    Элемент позволяет указать возможность купить соответствующий товар в розничном магазине.
    Возможные значения:
    1) false — возможность покупки в розничном магазине отсутствует;
    2) true — товар можно купить в розничном магазине.
    Необязательный элемент.

    pickup
    Элемент позволяет указать возможность зарезервировать выбранный товар и забрать его самостоятельно.
    Возможные значения:
    1) false — возможность «самовывоза» отсутствует;
    2) true — товар можно забрать самостоятельно.
    Необязательный элемент.

    delivery
    Элемент позволяет указать возможность доставки соответствующего товара.
    Возможные значения:
    1) false — товар не может быть доставлен;
    2) true — товар доставляется на условиях, которые описываются в партнерском интерфейсе на странице Параметры размещения.
    Необязательный элемент.

    local_delivery_cost
    Стоимость доставки данного товара в своем регионе.
    Необязательный элемент.

    name
    Название товарного предложения. В названии упрощенного предложения рекомендуется указывать наименование и код производителя.
    Обязательный элемент.

    vendor
    Производитель. Не отображается в названии предложения.
    Необязательный элемент.

    vendorCode
    Код товара (указывается код производителя). Не отображается в названии предложения.
    Необязательный элемент.

    description
    Описание товарного предложения. Длина текста не более 175 символов (не включая знаки препинания), запрещено использовать HTML-теги (информация внутри тегов публиковаться не будет).
    Необязательный элемент.

    sales_notes
    Элемент используется для отражения информации о минимальной сумме заказа, минимальной партии товара или необходимости предоплаты, а так же для описания акций, скидок и распродаж. Допустимая длина текста в элементе — 50 символов.
    Необязательный элемент.

    manufacturer_warranty
    Элемент предназначен для отметки товаров, имеющих официальную гарантию производителя.
    Необязательный элемент.
    Возможные значения:
    1) false — товар не имеет официальной гарантии;
    2) true — товар имеет официальную гарантию.

    country_of_origin
    Элемент предназначен для указания страны производства товара. Список стран, которые могут быть указаны в этом элементе, доступен по адресу: http://partner.market.yandex.ru/pages/help/Countries.pdf.
    Примечание. Если вы хотите участвовать в программе «Заказ на Маркете», то желательно указывать данный элемент в YML-файле.
    Необязательный элемент.

    adult
    Элемент обязателен для обозначения товара, имеющего отношение к удовлетворению сексуальных потребностей, либо иным образом эксплуатирующего интерес к сексу.
    Необязательный элемент.

    age
    Возрастная категория товара. Годы задаются с помощью атрибута unit со значением year, месяцы — с помощью атрибута unit со значением month.
    Допустимые значения параметра при unit="year": 0, 6, 12, 16, 18. Допустимые значения параметра при unit="month": 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12.
    Необязательный элемент.

    barcode
    Штрихкод товара, указанный производителем.
    Необязательный элемент. Элемент <offer> может содержать несколько элементов <barcode>.

    cpa
    Элемент предназначен для управления участием товарных предложений в программе «Заказ на Маркете».
    Необязательный элемент.

    param
    Элемент предназначен для указания характеристик товара. Для описания каждого параметра используется отдельный элемент <param>.
    Необязательный элемент. Элемент <offer> может содержать несколько элементов <param>.
    """

    def __init__(self):
        self.id = 0
        self.url = None
        self.price = None
        self.oldprice = None
        self.currencyId = None
        self.categoryId = None
        self.market_category = None
        self.pictures = []
        '''
        Добавление изображений pictures_append(picture)
        '''
        self.store = False
        self.pickup = False
        self.delivery = False
        self.local_delivery_cost = None
        self.name = None
        self.vendor = None
        self.vendorCode = None
        self.description = None
        self.sales_notes = None
        self.manufacturer_warranty = None
        self.country_of_origin = None
        self.adult = None
        self.age = None
        self.age_unit = None
        self.barcode = None
        self.cpa = None
        self.params = []
        '''
        Добавление изображений params_append(picture)
        '''

    def pictures_append(self, url):
        self.pictures.append(url)

    def params_append(self, param_name, param_value):
        self.params.append({'name': param_name, 'value': param_value})

    def validate(self):
        if self.price is None or self.currencyId is None or self.categoryId is None or self.name is None:
            # Not valid offer
            raise Exception(u"Поля price, currencyId, categoryId, name обязательны")


from django import template
from virtenviro.news.models import Post
from django.template import loader, Context
from django.conf import settings

register = template.Library()


class LastNewsNode(template.Node):
    def __init__(self, count):
        self.news = Post.objects.last_news()[0:count]

    def render(self, context):
        context['last_news'] = self.news
        return ''

@register.tag
def last_news(parser, token):
    contents = token.split_contents()
    if contents[1]:
        try:
            count = int(contents[0])
        except TypeError:
            try:
                count = settings.LAST_NEWS_COUNT
            except:
                count = 10
    return LastNewsNode(count=count)


#~*~ coding: utf-8 ~*~
from mptt.managers import TreeManager
from virtenviro.shop.models import *


class ImageManager(TreeManager):
    def get_one_image(self, product, image_type):
        try:
            image = self.get(product = product, image_type = image_type)
        except Image.DoesNotExist:
            image = None
        return image


class ModelManager(models.Manager):
    def get_product(self, slug):
        try:
            return self.get(slug=slug)
        except Product.DoesNotExist:
            return None
        except Product.MultipleObjectsReturned:
            return None

    def get_product_by_id(self, id):
        try:
            return self.get(id=id)
        except Product.DoesNotExist:
            return None


class PropertyManager(models.Manager):
    def grouped(self, property_type=None):
        if property_type is None:
            return []

        return self.filter(property_type=property_type).values('value').annotate(dcount=models.Count('value'))

    def by_type(self, property_type, product):
        additional_properties = self.filter(property_type=property_type, product=product)

        return additional_properties

    def make_filter(self, property_type, **fkwargs):
        objs = self.grouped(property_type=property_type).\
            filter(**fkwargs).extra(
            select={
                'intval': 'CAST(substring(value FROM \'^[0-9]+\') AS INTEGER)'},
            order_by=['intval', 'value'])

        objs_grouped = []
        for obj in objs:
            objs_grouped.append({
                'value': obj['value'],
                'image': self.get_image(obj['value'], property_type)})
        return objs_grouped

    def get_image(self, property_value, property_type):
        try:
            pr = self.filter(value=property_value, property_type=property_type)[0]
            ps = Product.objects.filter(property__value=pr.value, property__property_type=pr.property_type)
            return Image.objects.filter(is_main=True, product__in=ps)[0]
        except:
            return None


class PropertySlugManager(models.Manager):
    def generate(self, property_type):
        # get all properties grouped where property_type = property_type
        properties_grouped = Property.objects.grouped(
            property_type=property_type).extra(
            select={'intval': 'CAST(substring(value FROM \'^[0-9]+\') AS INTEGER)'},
            order_by=['intval', 'value'])

        for property_grouped in properties_grouped:
            # get PropertySlug or create
            property_slug = self.get_or_create(
                value=property_grouped.value,
                property_type=property_type,
                defaults={
                    'slug': set_slug(PropertySlug, property_grouped.value, 60)
                })


#~*~ coding: utf-8 ~*~
__author__ = 'Kamo Petrosyan'


class Vendor:
    def __init__(self, name, shortTitle=None, slug=None, description=None, logo=None, country=None,
                 city=None, address=None, ordering=None, publish=True):
        """

        :type logo: str
        """
        if logo.startswith('/'):
            logo = logo[1:]

        self.name = name
        self.shortTitle = shortTitle
        self.slug = slug
        self.description = description
        self.logo = logo
        self.country = country
        self.city = city
        self.ordering = ordering
        self.publish = publish



# ~*~ coding: utf-8 ~*~
__author__ = 'Kamo Petrosyan'
from django.shortcuts import render, redirect
from django.contrib.admin.views.decorators import staff_member_required

template_str = 'virtenviro/admin/%s'


@staff_member_required
def index(request):
    context = {}
    return render(request, template_str % 'index.html', context)


@staff_member_required
def shop(request):

    template = 'virtenviro/admin/shop/home.html'
    context = {
        'appname': 'shop',
    }
    return render(request, template, context)


#~*~ coding: utf-8 ~*~
from django.contrib.auth.decorators import login_required
from django.http import JsonResponse
from django.shortcuts import render
from lxml import etree

from forms import SimpleXmlImportForm
from models import *
from virtenviro.logger import Logger
from virtenviro.utils import id_generator, handle_uploads

MEDIA_ROOT = getattr(settings, 'MEDIA_ROOT', getattr(settings, 'STATIC_ROOT'))

@login_required
def set_order_status(request, order_id, status_id):
    context = {'res': False, 'errors': []}
    try:
        order = Order.objects.get(pk=order_id, user=request.user)
        try:
            status = OrderStatus.objects.get(pk=status_id)
            order.status = status
            order.save()
            context['res'] = True
        except OrderStatus.DoesNotExist:
            context['errors'].append('Status does not exist')
    except Order.DoesNotExist:
        context['errors'].append('Order does not exist')

    return JsonResponse(context)


@login_required
def import_yml(request):
    from yml_import import YmlParser
    from virtenviro.shop.yml_import.yml2product import YML2Product
    if request.method == 'POST':
        form = SimpleXmlImportForm(request.POST, request.FILES)
        if form.is_valid():
            saved_file = handle_uploads(request, ['xml_file',])['xml_file']
            yml_parser = YmlParser(saved_file)
            yml = yml_parser.parse()
            y2p = YML2Product(yml=yml)
            y2p.run()
    else:
        form = SimpleXmlImportForm()

    return render(request, 'virtenviro/admin/shop/import_yml.html', {'form': form, 'appname': 'shop'})


def import_simple_xml(request):
    if request.method == 'POST':
        form = SimpleXmlImportForm(request.POST, request.FILES)
        if form.is_valid():
            saved_file = handle_uploads(request, ['xml_file',])['xml_file']
            xml_import(init_tree(saved_file))
    else:
        form = SimpleXmlImportForm()

    return render(request, 'virtenviro/shop/xmlimport.html', {'form': form,})


def init_tree(xml_file):
    parser = etree.XMLParser(remove_blank_text=True)
    return etree.parse(xml_file, parser)


def xml_import(tree):
    for xml_product in tree.findall('.//product'):
        xml_name = xml_product.find('name').text
        try:
            try:
                xml_category = xml_product.find('category').text
            except:
                xml_category = ''
            try:
                xml_description = xml_product.find('description').text
            except:
                xml_description = ''
            try:
                xml_manufacturer = xml_product.find('manufacturer').text
            except:
                xml_manufacturer = ''
            try:
                xml_articul = xml_product.find('articul').text
            except:
                xml_articul = id_generator(15)
            '''
            unique_code_string = unicode.join(u'', [xml_name, xml_manufacturer, xml_articul])
            unique_code = sha256(unique_code_string)
            '''

            if not xml_manufacturer == '':
                manufacturer, created = Manufacturer.objects.get_or_create(name=xml_manufacturer)
            else:
                manufacturer = None

            if not xml_category == '':
                category, created = Category.objects.get_or_create(name=xml_category, defaults={
                    'parent': None
                })
            else:
                category = None

            product, created = Product.objects.get_or_create(
                name=xml_name,
                manufacturer=manufacturer,
                category=category,
                defaults={
                    'slug': slugify(xml_name),
                    'description': xml_description,
                    'articul': xml_articul
                }
            )
            '''

            product = Product(
                name=xml_name,
                description=xml_description,
                category=category,
                manufacturer=manufacturer,
                articul=xml_articul,
                unique_code=unique_code
            )
            product.save()
            '''

            for xml_image in xml_product.findall('photo'):
                xml_image_attribs = xml_image.attrib
                if xml_image_attribs.get('type', False):
                    image_type, created = ImageType.objects.get_or_create(name=xml_image_attribs['type'])
                else:
                    image_type = None
                if not category is None:
                    image_type_category, created = ImageTypeCategoryRelation.objects.get_or_create(
                        image_type=image_type,
                        category=category,
                        defaults={
                            'max_count': 4
                        }
                    )
                image = Image()
                image.name = product.name
                image.image = '/img/shop/'+xml_image.text
                image.image_type = image_type
                image.product = product
                image.is_main = False if product.has_main_image() else True
                image.save()

            for xml_property in xml_product.findall('property'):
                if xml_property.text:
                    xml_property_attribs = xml_property.attrib
                    property_type, created = PropertyType.objects.get_or_create(
                        name=xml_property_attribs['name'],
                        defaults={
                            'data_type': xml_property_attribs.get('type', -3)
                        }
                    )
                    if category:
                        property_type_category_relation = PropertyTypeCategoryRelation.objects.get_or_create(
                            property_type=property_type,
                            category=category,
                            defaults={
                                'max_count': 1,
                            }
                        )

                    property, created = Property.objects.get_or_create(
                        property_type=property_type,
                        value=xml_property.text,
                        product=product
                    )
        except Exception as inst:
            src = '%s\t|\t can not import' % xml_name
            src = '%s\t|\t%s\t|\t%s' % (src, type(inst), inst.args)
            logger = Logger('import_xml.txt', src)



'''
def create_image(url, title, product, image_type_name = None, download=False):
    try:
        image_type = ImageType.objects.get(name=image_type_name)
    except ImageType.DoesNotExist:
        image_type = ImageType()
        image_type.name = u'Сертификаты'
        image_type.save()
    image = Image()
    image.image_type = image_type
    image_upload_path = os.path.join(settings.STATIC_ROOT, 'files', 'certificate')
    if not os.path.exists(image_upload_path):
        os.makedirs(image_upload_path)
    certificate_file = os.path.join(image_upload_path, '{}.{}'.format(id_generator(12, url.split('.')[-1])))
    if download == True:
        f = open(certificate_file, 'wb')
        opener = urllib2.build_opener()
        opener.addheaders = [('User-Agent', 'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/34.0.1847.137 Safari/537.36')]
        response = opener.open(url)
        data = response.read()
        f.write(data)
        f.close()
    else:
        import shutil
        shutil.copyfile(url, certificate_file)
    image.image = certificate_file
    image.product = product
    image.save()
'''



# ~*~ coding: utf-8 ~*~
__author__ = 'Kamo Petrosyan'


class Category:
    def __init__(self, name, description=None, parent=None, slug=None, ordering=99999):
        self.id = 0
        self.name = name
        self.description = description
        self.slug = slug
        self.ordering = ordering
        self.parent = parent




# ~*~ coding: utf-8 ~*~
__author__ = 'Kamo Petrosyan'
from django.shortcuts import render, redirect
from django.contrib.admin.views.decorators import staff_member_required
from django.http import Http404
from django.utils.http import urlquote
from django.conf import settings
from virtenviro.content.models import *
from virtenviro.content.admin_forms import *
from virtenviro.utils import paginate

template_str = 'virtenviro/admin/content/{}'


@staff_member_required
def content_page(request):
    template = template_str.format('change_list.html')

    context = {
        'pages': Page.objects.filter(parent__isnull=True),
    }

    return render(request, template, context)


@staff_member_required
def content_page_edit(request, page_id):
    template = template_str.format('page_form.html')
    context = {}

    try:
        page = Page.objects.get(pk=page_id)
        context['current_page'] = page
    except Page.DoesNotExist:
        raise Http404

    initials = []
    content_forms = {}
    for lang in settings.LANGUAGES:
        if page.get_content(language=lang) is None:
            initials.append({'language': lang[0], 'author': request.user})

    if request.method == 'POST':
        page_form = PagesAdminForm(request.POST, instance=page, prefix='page')
        for lang in settings.LANGUAGES:
            try:
                content = page.contents.get(language=lang[0])
                content_forms[lang[0]] = ContentAdminForm(request.POST, instance=content,
                                                          prefix='content_{}'.format(lang[0]))
            except Content.DoesNotExist:
                content_forms[lang[0]] = ContentAdminForm(request.POST, initial={'language': lang[0]},
                                                          prefix='content_{}'.format(lang[0]))

        if page_form.is_valid():
            is_valid = True
            page = page_form.save()
            for lang in settings.LANGUAGES:
                if content_forms[lang[0]].has_changed() and content_forms[lang[0]].is_valid():
                    content_forms[lang[0]].save()
                else:
                    is_valid = False
    else:
        page_form = PagesAdminForm(instance=page, prefix='page')
        for lang in settings.LANGUAGES:
            try:
                content = page.contents.get(language=lang[0])
                content_forms[lang[0]] = ContentAdminForm(instance=content,
                                                          prefix='content_{}'.format(lang[0]))
            except Content.DoesNotExist:
                content_forms[lang[0]] = ContentAdminForm(initial={'language': lang[0]},
                                                          prefix='content_{}'.format(lang[0]))

    context['page'] = page
    context['pages'] = Page.objects.all()
    context['page_form'] = page_form
    context['content_forms'] = content_forms

    return render(request, template, context)


@staff_member_required
def content_page_add(request):
    template = template_str.format('page_form.html')
    context = {}

    initials = []
    content_forms = {}
    for lang in settings.LANGUAGES:
        initials.append({'language': lang[0], 'author': request.user})

    if request.method == 'POST':
        page_form = PagesAdminForm(request.POST)
        for lang in settings.LANGUAGES:
            content_forms[lang[0]] = ContentAdminForm(request.POST, initial={'language': lang[0]},
                                                      prefix='content_{}'.format(lang[0]))

        if page_form.is_valid():
            is_valid = True
            page = page_form.save()
            for lang in settings.LANGUAGES:
                if content_forms[lang[0]].has_changed() and content_forms[lang[0]].is_valid():
                    content_forms[lang[0]].save()
                else:
                    is_valid = False
            return redirect('vadmin:content_page_edit', page.pk)
    else:
        page_form = PagesAdminForm()
        for lang in settings.LANGUAGES:
            content_forms[lang[0]] = ContentAdminForm(initial={'language': lang[0]},
                                                      prefix='content_{}'.format(lang[0]))

    context['pages'] = Page.objects.all()
    context['page_form'] = page_form
    context['content_forms'] = content_forms

    return render(request, template, context)




from django.conf.urls import *
from django.conf import settings


SLUG_REGEXP = '[0-9A-Za-z-_.//]+'
if settings.APPEND_SLASH:
    regexp = r'^(?P<slug>%s)/$' % SLUG_REGEXP
else:
    regexp = r'^(?P<slug>%s)/$' % SLUG_REGEXP

urlpatterns = patterns('',
    url(r'^$', 'virtenviro.content.views.home', name='home'),
    url(r'^[a-z0-9-_/]+$', 'virtenviro.content.views.view', name='page'),
)


# ~*~ coding: utf-8 ~*~
__author__ = 'Kamo Petrosyan'
from django.template import Library, loader, Context
from virtenviro.content.models import Page

register = Library()

@register.simple_tag
def page_navigation(current_page=None):
    t = loader.get_template('virtenviro/admin/content/navigation.html')
    pages = Page.objects.filter(parent__isnull=True).order_by('title')
    content = t.render(Context({'nodes': pages, 'current_page': current_page}))
    return content


@register.assignment_tag(takes_context=True)
def get_from_dict(context, d, key):
    return d[key]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('content', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='page',
            managers=[
            ],
        ),
        migrations.AlterModelManagers(
            name='template',
            managers=[
            ],
        ),
        migrations.AlterField(
            model_name='page',
            name='miniature',
            field=models.ImageField(upload_to=b'/srv/www/virtenviro/../media/img/miniature', null=True, verbose_name='Miniature', blank=True),
        ),
    ]



# ~*~ coding: utf-8 ~*~
__author__ = 'Kamo Petrosyan'
from lxml import etree
from offer import Offer
from yml import YML


def get_text(node, default=None):
        res = default
        try:
            res = node.text
        except AttributeError:
            pass
        except Exception, e:
            print(e.message)
        return res


class YmlParser:

    def __init__(self, yml_file):
        parser = etree.XMLParser(remove_blank_text=True)
        self.yml_tree = etree.parse(yml_file, parser)
        self.yml = YML()

    def parse(self):
        self.parse_categories()
        self.parse_currencies()
        self.parse_shop()
        self.parse_offers()
        return self.yml

    def parse_categories(self):
        categories_tree = self.yml_tree.find('.//categories')
        for category_xml in categories_tree.findall('category'):
            category_name = category_xml.text
            parent_id = category_xml.attrib.get('parentId')
            self.yml.category_append(category=category_name, parent=parent_id)

    def parse_currencies(self):
        currencies_tree = self.yml_tree.find('.//currencies')
        for currency_xml in currencies_tree.findall('currency'):
            currency_attrib = currency_xml.attrib
            if not currency_attrib.get('id', False):
                continue
            self.yml.currency_append(currency_id=currency_attrib.get('id'),
                                     rate=currency_attrib.get('rate', None),
                                     plus=currency_attrib.get('plus', None))

    def parse_shop(self):
        shop_tree = self.yml_tree.find('.//shop')
        self.yml.shop = {
            'name': get_text(shop_tree.find('name')),
            'company': get_text(shop_tree.find('company')),
            'url': get_text(shop_tree.find('url')),
            'platform': get_text(shop_tree.find('platform')),
            'version': get_text(shop_tree.find('version')),
            'agency': get_text(shop_tree.find('agency')),
            'email': get_text(shop_tree.find('email')),
        }
        self.yml.cpa = get_text(shop_tree.find('cpa'))

    def parse_offers(self):
        offer_tree = self.yml_tree.find('.//offers')
        for offer_xml in offer_tree.findall('offer'):
            offer = Offer()
            offer.url = get_text(offer_xml.find('url'))
            offer.price = float(get_text(offer_xml.find('price'), 0.0))
            offer.oldprice = float(get_text(offer_xml.find('oldprice'), 0.0))
            offer.currencyId = get_text(offer_xml.find('currencyId'))
            offer.categoryId = get_text(offer_xml.find('categoryId'))
            for picture in offer_xml.findall('picture'):
                offer.pictures_append(get_text(picture))
            offer.store = get_text(offer_xml.find('store'), 'false')
            offer.pickup = get_text(offer_xml.find('pickup'), 'false')
            offer.delivery = get_text(offer_xml.find('delivery'), 'false')
            offer.local_delivery_cost = get_text(offer_xml.find('local_delivery_cost'))
            offer.name = get_text(offer_xml.find('name'))
            offer.vendor = get_text(offer_xml.find('vendor'))
            offer.vendorCode = get_text(offer_xml.find('vendorCode'))
            offer.description = get_text(offer_xml.find('description'))
            offer.sales_notes = get_text(offer_xml.find('sales_notes'))
            offer.manufacturer_warranty = get_text(offer_xml.find('manufacturer_warranty'))
            offer.country_of_origin = get_text(offer_xml.find('country_of_origin'))
            offer.age = get_text(offer_xml.find('age'))
            if not offer.age is None:
                offer.age_unit = offer_xml.find('age').attrib.get('unit', None)
            offer.barcode = get_text(offer_xml.find('barcode'))
            offer.cpa = get_text(offer_xml.find('cpa'))
            for param_xml in offer_xml.findall('param'):
                try:
                    param_value = get_text(param_xml)
                    param_name = param_xml.attrib.get('name', None)
                    if not param_value is None and not param_name is None:
                        offer.params_append(param_name=param_name, param_value=param_value)
                except AttributeError:
                    pass

            self.yml.offers_append(offer, validate=False)




#~*~ coding: utf-8 ~*~
import os
from django.conf.urls import patterns, include, url
from django.conf import settings
from django.contrib import admin
from filebrowser.sites import site

urlpatterns = patterns('',
    # Examples:
    # url(r'^$', 'virtenviro.views.home', name='home'),
    # url(r'^blog/', include('blog.urls')),

    url(r'^filebrowser/', include(site.urls)),
    url(r'^admin/', include(admin.site.urls)),
    url(r'^accounts/', include('virtenviro.registration.urls')),
    url(r'^vadmin/', include('virtenviro.admin.urls'))
)

if settings.DEBUG:
    urlpatterns += patterns('',
        url(r'^static/(?P<path>.*)$', 'django.views.static.serve',
            {'document_root': settings.STATIC_ROOT}),
        url(r'^media/(?P<path>.*)$', 'django.views.static.serve',
            {'document_root': settings.MEDIA_ROOT}),)

urlpatterns += patterns('',
    url(r'^', include('virtenviro.content.urls')),
)


# ~*~ coding: utf-8 ~*~
import os
from django.db import models
from django.utils.translation import ugettext_lazy as _
from mptt.models import MPTTModel, TreeForeignKey
from filebrowser.fields import FileBrowseField
from django.conf import settings
from virtenviro.shop.managers import *
from virtenviro.utils import set_slug, sha256, id_generator
from virtenviro.abstract_models import AbstractSeo, AbstractContentMultilingual
from pytils.translit import slugify
from django.contrib.auth.models import User

MEDIA_ROOT = getattr(settings, 'MEDIA_ROOT', getattr(settings, 'STATIC_ROOT'))


class Category(MPTTModel):
    name = models.CharField(max_length=255, verbose_name=_('Name'))
    slug = models.CharField(max_length=60, verbose_name=_('Slug'), null=True, blank=True)
    parent = TreeForeignKey('self', verbose_name=_('Parent'), related_name='subcategories', null=True, blank=True)
    description = models.TextField(verbose_name=_('Description'), null=True, blank=True)
    image = models.ImageField(upload_to=_(os.path.join(MEDIA_ROOT, 'img', 'shop', 'category')), verbose_name=_('Image'), null=True, blank=True)

    # SERVICE FIELDS
    ordering = models.IntegerField(default=0, verbose_name=_('Ordering'), blank=True, null=True)
    view_count = models.IntegerField(default=0, verbose_name=_('Count of views'), blank=True, null=True)

    # META FIELDS
    meta_title = models.CharField(max_length=250, verbose_name=_('Meta Title'), null=True, blank=True)
    meta_keywords = models.TextField(verbose_name=_('Meta Keywords'), null=True, blank=True)
    meta_description = models.TextField(verbose_name=_('Meta Description'), null=True, blank=True)

    def __unicode__(self):
        return self.name

    def clean(self):
        if not self.slug:
            self.slug = set_slug(Category, self.name, length=60)

    def get_absolute_url(self):
        if self.parent is None:
            return '/%s/' % self.slug
        else:
            url = self.get_all_ancestors(self.parent, self.slug)
        return '%s' % url

    get_absolute_url.short_description = _('URL')

    def get_all_ancestors(self, parent, url=''):
        url = '%s/%s' % (parent.slug, url)
        if parent.parent:
            return self.get_all_ancestors(parent.parent, url)
        else:
            return '/%s/' % url

    class Meta:
        ordering = ['name']
        verbose_name = _('Category')
        verbose_name_plural = _('Categories')


class Product(models.Model):
    name = models.CharField(max_length=255, verbose_name=_('Name'))
    slug = models.CharField(max_length=60, verbose_name=_('Slug'), null=True, blank=True)
    category = models.ForeignKey(Category, verbose_name=_('Category'), related_name='children', null=True, blank=True)
    subcategory = models.ManyToManyField(Category, verbose_name=_('Subcategory'), related_name='products', blank=True)
    articul = models.CharField(max_length=200, verbose_name=_('Articul'), null=True, blank=True)
    '''
    Так как не удалось при импорте сгенерировать корректные unique_code, и данные могут быть не полные или не совпадать,
    то решено временно или навсегда удалить это поле
    #unique_code = models.CharField(max_length=250, verbose_name=_('Unique code'), unique=True, blank=True)
    '''
    description = models.TextField(verbose_name=_('Description'), null=True, blank=True)
    price = models.FloatField(verbose_name=_('Price'), default=0.0)
    discount = models.FloatField(verbose_name=_('Discount'), default=0)
    manufacturer = models.ForeignKey('Manufacturer', verbose_name=_('Manufacturer'), null=True, blank=True)

    # SERVICE FIELDS
    ordering = models.IntegerField(default=0, verbose_name=_('Ordering'), blank=True, null=True)
    view_count = models.IntegerField(default=0, verbose_name=_('Count of views'), blank=True, null=True)

    # META FIELDS
    meta_title = models.CharField(max_length=250, verbose_name=_('Meta Title'), null=True, blank=True)
    meta_keywords = models.TextField(verbose_name=_('Meta Keywords'), null=True, blank=True)
    meta_description = models.TextField(verbose_name=_('Meta Description'), null=True, blank=True)

    objects = ProductManager()

    def __unicode__(self):
        return self.name

    def new_price(self):
        discount = self.discount/100
        price = self.price - self.price * discount
        return price

    def clean(self, *args, **kwargs):
        if not self.slug:
            self.slug = set_slug(Product, self.name, length=60)

        if not self.articul:
            self.articul = id_generator(size=15)
        '''
        if not self.unique_code:
            if self.manufacturer:
                manufacturer = self.manufacturer.name
            else:
                manufacturer = ''
            unique_code_string = '{}{}{}'.format(self.name, manufacturer, self.articul)
            self.unique_code = sha256(unique_code_string)
        '''

    def get_main_images(self):
        return self.image_set.all().filter(is_main=True)

    def get_main_image(self):
        main_images = self.image_set.all().filter(is_main=True)
        if not main_images:
            return None
        else:
            return main_images[0]

    def has_main_image(self):
        if self.image_set.all().filter(is_main=True):
            return True
        else:
            return False
        return False

    def filter_group(self):
        return self.filter(is_group=True)

    def filter_parent_group(self):
        return self.filter(is_group=True, parent__isnull=True)

    def create_subcategories_from_property(self, property_type):
        _properties = self.property_set.filter(property_type=property_type)
        if _properties:
            for _property in _properties:
                category_parent, created = Category.objects.get_or_create(
                    name=_property.property_type.name,
                    defaults={
                        'slug': slugify(_property.property_type.name),
                    }
                )
                category, created = Category.objects.get_or_create(
                    name=_property.value,
                    parent=category_parent,
                    defaults={
                        'slug': slugify(_property.value),
                    }
                )
                if not category in self.subcategory:
                    self.subcategory.add(category)

    def get_absolute_url(self):
        return '%s%s/' % (self.category.get_absolute_url(), self.slug)

    get_absolute_url.short_description = _('URL')

    class Meta:
        ordering = ['ordering', 'name']
        verbose_name = _('Product')
        verbose_name_plural = _('Products')

    class MPTTMeta:
        order_insertion_by = ['ordering', 'name']


class PropertyType(models.Model):
    DATA_TYPES = (
        (-1, _('Integer'),),
        (-2, _('Float')),
        (-3, _('String')),
        (-4, _('Text')),
        (-5, _('Boolean')),
        (-6, _('Html')),
    )
    name = models.CharField(max_length=255, verbose_name=_('Name'))
    category = models.ManyToManyField(Category, through='PropertyTypeCategoryRelation')
    data_type = models.IntegerField(verbose_name=_('Data type'), default=-1, choices=DATA_TYPES)

    def __unicode__(self):
        return '%s [%s]' % (self.name, self.pk)

    class Meta:
        ordering = ['name']
        verbose_name = _('Properties type')
        verbose_name_plural = _('Properties Types')


class PropertyTypeCategoryRelation(models.Model):
    property_type = models.ForeignKey(PropertyType, verbose_name=_('Property Type'))
    category = models.ForeignKey(Category, verbose_name=_('Category'))
    # Set maximum number of Property types for category to economy space
    max_count = models.IntegerField(
        default=1,
        verbose_name=_('Count'),
        help_text=_('Maximum number of properties by this property type in category'))
    # slug to create groups of filters as pages
    slug = models.CharField(max_length=60, verbose_name=_('Slug'), null=True, blank=True)

    def __unicode__(self):
        return '%s for %s' % (self.property_type.name, self.category.name)


class Property(models.Model):
    property_type = models.ForeignKey(PropertyType)
    value = models.TextField(verbose_name=_('Value'))
    product = models.ForeignKey(Product, verbose_name=_('Product'))

    objects = PropertyManager()

    def __unicode__(self):
        return '%s: %s' % (self.property_type.name, self.value)

    class Meta:
        ordering = ['property_type__name', 'value']
        verbose_name = _('Property')
        verbose_name_plural = _('Properties')


class PropertySlug(models.Model):
    """
    This class created to make available create pages categories of goods with filtration by
    property type and property value.
    For example:
        You have shorts.
        You can group them by property_type "Color". There will be all properties by "color", grouped by "value"
        You can then get all shorts with color "Red"
    """
    property_type = models.ForeignKey(PropertyType, verbose_name=_('Propert type'))
    value = models.TextField(verbose_name=_('Value'))
    slug = models.CharField(max_length=60, verbose_name=_('Slug'))
    objects = PropertySlugManager()

    def __unicode__(self):
        return '%s: %s' % (self.property_type.name, self.value)

    class Meta:
        ordering = ['value']
        verbose_name = _('Property slug')
        verbose_name_plural = _('Property slugs')


class File(models.Model):
    file = FileBrowseField("File", max_length=200, directory="files/", blank=True, null=True)
    name = models.CharField(max_length=255, verbose_name=_('Name'), blank=True, null=True)
    product = models.ForeignKey(Product, verbose_name=_('Product'))

    def __unicode__(self):
        return self.file.url


class ImageType(models.Model):
    name = models.CharField(max_length=255, verbose_name=_('Name'))
    category = models.ManyToManyField(Category, verbose_name=_('Production Type'),
                                      through='ImageTypeCategoryRelation')
    '''
    def clean(self):
        from django.core.exceptions import ValidationError
        self.images_path = '%s' % self.images_path
    '''

    def __unicode__(self):
        return self.name

    class Meta:
        ordering = ['name']
        verbose_name = _('Images Type')
        verbose_name_plural = _('Images Types')


class ImageTypeCategoryRelation(models.Model):
    image_type = models.ForeignKey(ImageType, verbose_name=_('Image type'))
    category = models.ForeignKey(Category, verbose_name=_('Category'))
    max_count = models.IntegerField(default=1, verbose_name=_('Count'),
                                    help_text=_('Maximum number of images by this image type in category'))

    def __unicode__(self):
        return '%s for %s' % (self.image_type.name, self.category.name)


class Image(models.Model):
    image = FileBrowseField("Image", max_length=200, directory=os.path.join(MEDIA_ROOT, 'img', 'shop'),
                            blank=True, null=True)
    name = models.CharField(max_length=255, verbose_name=_('Name'), blank=True, null=True)
    product = models.ForeignKey(Product, verbose_name=_('Product'))
    image_type = models.ForeignKey(ImageType, verbose_name=_('Image Type'))
    is_main = models.BooleanField(default=False, verbose_name=_('Is Main'))

    def __unicode__(self):
        return '%s [%s%s]' % (self.name, MEDIA_ROOT, self.image)

    class Meta:
        ordering = ['image_type', 'name']
        verbose_name = _('Image')
        verbose_name_plural = _('Images')


class Manufacturer(models.Model):
    name = models.CharField(max_length=255, verbose_name=_('Manufacturer'), unique=True)
    description = models.TextField(verbose_name=_('Description'), blank=True, null=True)
    slug = models.CharField(max_length=60, verbose_name=_('Slug'), null=True, blank=True)
    logo = models.ImageField(upload_to=os.path.join(MEDIA_ROOT, 'img', 'shop', 'manufacturers'), verbose_name=_('Logo'),
                             null=True, blank=True)

    # Contacts
    country = models.CharField(max_length=150, verbose_name=_('Country'), blank=True, null=True)
    city = models.CharField(max_length=150, verbose_name=_('City'), blank=True, null=True)
    address = models.CharField(max_length=255, verbose_name=_('Address'), blank=True, null=True)
    phones = models.TextField(verbose_name=_('Phones'), blank=True, null=True)

    def __unicode__(self):
        return self.name

    class Meta:
        ordering = ['name']
        verbose_name = _('Manufacturer')
        verbose_name_plural = _('Manufacturers')


# todo: Discount class
# todo: Delivery
# todo: payment modules
# todo: Currency class
class Currency(models.Model):
    name = models.CharField(max_length=50, verbose_name=_('Currency'))
    default = models.BooleanField(default=False, verbose_name=_('Is default currency'))
    symbol = models.CharField(max_length=10, verbose_name=_('Symbol'), blank=True, null=True)
    char_code = models.CharField(max_length=10, verbose_name=_('Char code of currency'), blank=True, null=True)
    num_code = models.IntegerField(verbose_name=_('Code of currency'), blank=True, null=True)
    nominal = models.FloatField(verbose_name=_('Nominal'), blank=True, null=True)
    value = models.FloatField(verbose_name=_('Value'), blank=True, null=True)

    def __unicode__(self):
        return self.name

    class Meta:
        ordering = ['name']
        verbose_name = _('Currency')
        verbose_name_plural = _('Currencies')


class Seller(models.Model):
    name = models.CharField(max_length=255, verbose_name=_('Name'))
    description = models.TextField(verbose_name=_('Description'), null=True, blank=True)
    slug = models.CharField(max_length=60, verbose_name=_('Slug'))
    image = models.ImageField(upload_to=os.path.join(MEDIA_ROOT, 'img', 'shop', 'sellers'), verbose_name=_('Image'),
                              null=True, blank=True)

    # Contacts
    address = models.CharField(max_length=255, verbose_name=_('Address'), null=True, blank=True)
    city = models.CharField(max_length=255, verbose_name=_('City'), null=True, blank=True)
    country = models.CharField(max_length=255, verbose_name=_('Country'), null=True, blank=True)
    postal_zip = models.CharField(max_length=255, verbose_name=_('ZIP'), null=True, blank=True)
    site = models.URLField(verbose_name=_('Site'), null=True, blank=True)
    email = models.EmailField(verbose_name=_('Email'), null=True, blank=True)
    phones = models.TextField(verbose_name=_('Phones'), null=True, blank=True)
    itn = models.CharField(max_length=255, verbose_name=_('Individual Taxpayer Number'), null=True, blank=True)

    # Service
    ordering = models.IntegerField(verbose_name=_('Ordering'), default=999)
    map_code = models.TextField(verbose_name=_('Map\'s code'), null=True, blank=True)

    def __unicode__(self):
        return self.name

    class Meta:
        ordering = ['ordering', 'name']
        verbose_name = _('Seller')
        verbose_name_plural = _('Sellers')

# todo: Warehouse
# todo: Add statistics
# todo: Orders


class OrderStatus(models.Model):
    name = models.CharField(max_length=60, verbose_name=_('Name'))

    def __unicode__(self):
        return self.name

    class Meta:
        ordering = ['name']
        verbose_name = _('Order status')
        verbose_name_plural = _('Order statuses')


class Order(models.Model):
    product = models.ManyToManyField(Product,
                                     verbose_name=_('Product'),
                                     through='ProductOrderRelation',
                                     related_name='production')
    user = models.ForeignKey(User, verbose_name=_('User'))
    created_time = models.DateTimeField(auto_now_add=True)
    modified_time = models.DateTimeField(auto_now=True)
    status = models.ForeignKey(OrderStatus, verbose_name=_('Status'),)

    def __unicode__(self):
        return '%s' % self.id

    def summary(self):
        pors = self.productorderrelation_set.all()
        sum = 0
        for p in pors:
            sum += (p.product.new_price() * p.count)
        return sum

    def summary_count(self):
        pors = self.productorderrelation_set.all()
        sum = 0
        for p in pors:
            sum += p.count
        return sum

    def summary_products(self):
        return self.productorderrelation_set.all().count()

    class Meta:
        ordering = ['-created_time']
        verbose_name = _('Order')
        verbose_name_plural = _('Orders')


class ProductOrderRelation(models.Model):
    order = models.ForeignKey(Order, verbose_name=_('Order'))
    product = models.ForeignKey(Product, verbose_name=_('Product'))
    count = models.IntegerField(default=1, verbose_name=_('Count'))

    def __unicode__(self):
        return '%s' % self.id




# ~*~ coding: utf-8 ~*~
__author__ = 'Kamo Petrosyan'
from category import Category
from vendor import Vendor

class YML:
    def __init__(self):
        self.offers = []
        self.categories = []
        self.vendors = []
        self.shop = {
            'name': None,
            'company': None,
            'url': '',
            'platform': None,
            'version': None,
            'agency': None,
            'email': None,
        }
        self.currencies = []
        self.cpa = None

    def category_append(self, category, description=None, parent=None, slug=None, ordering=99999):
        category = Category(name=category, description=description, slug=slug, ordering=ordering)
        # get parent
        if parent is not None:
            for cat in self.categories:
                if isinstance(parent, int) and cat.id == parent:
                    category.parent = cat
                    break
                elif isinstance(parent, str) and cat.name == parent:
                    category.parent = cat
                else:
                    category.parent = None
        if category not in self.categories:
            self.categories.append(category)

    def currency_append(self, currency_id, rate=None, plus=None):
        """

        :param currency_id:
        :param rate:
        :param plus: %
        :return:
        <currency id="USD" rate="CBRF" plus="1"/> - Курс доллара по ЦБРФ + 1%
        """
        for c in self.currencies:
            if c['id'] == currency_id:
                return

        if rate is None:
            rate = 'CBRF'

        currency = {'id': currency_id, 'rate': rate, 'plus': plus}
        self.currencies.append(currency)

    def offers_append(self, offer, validate=True):
        if validate and offer.validate():
            self.offers.append(offer)
        else:
            self.offers.append(offer)

    def vendor_add(self, name, shortTitle=None, slug=None, description=None, logo=None, country=None,
                   city=None, address=None, ordering=None, publish=True):
        vendor = Vendor(
            name=name,
            shortTitle=shortTitle,
            slug=slug,
            description=description,
            logo=logo,
            country=country,
            city=city,
            address=address,
            ordering=ordering,
            publish=publish)

        if vendor not in self.vendors:
            self.vendors.append(vendor)



# ~*~ coding: utf-8 ~*~
__author__ = 'Kamo Petrosyan'
from django.db import models
import datetime


class PageManager(models.Manager):
    def get_pages(self, parent=None, order=['ordering', '-pub_datetime', 'title'], author=None):
        pages = self.filter(published=True, pub_datetime__lte=datetime.datetime.now())
        if not parent is None:
            pages = pages.filter(
                level__lte=parent.level,
                tree_id=parent.tree_id,
                lft__gte=parent.lft,
                rght__lte=parent.rght)
        if not author is None:
            pages = pages.filter(author=author)
        return pages.order_by(*order)



# ~*~ coding: utf-8 ~*~
__author__ = 'Kamo Petrosyan'
from virtenviro.shop.models import *
from pytils.translit import slugify


class YML2Product:
    def __init__(self, yml):
        self.yml = yml
        self.categories = {}

    def run(self):
        self.add_categories()
        self.add_products()

    def add_categories(self):
        """
        Adds categories
        :return:
        """
        for yml_category in self.yml.categories:
            self.add_category(
                category_id=self.yml.categories.index(yml_category),
                category_name=yml_category['category'],
                parent=yml_category['parentId'])

    def add_category(self, category_id, category_name, parent):
        """

        :param : category_name String
        :param : parent int string or None (parentId)
        :rtype : Category
        """
        if not parent is None:
            yml_parent = self.yml.categories[int(parent)]
            parent = self.add_category(
                category_name=yml_parent['category'],
                parent=yml_parent['parentId'])

        category, created = Category.objects.get_or_create(name=category_name, parent=parent,
                                                           defaults={'slug': slugify(category_name)})
        self.categories[str(category.pk)] = category

        return category

    def add_products(self):
        for offer in self.yml.offers:
            self.add_product(offer)

    def add_product(self, offer):
        """

        :param offer: Offer
        :return: Product
        """
        if not offer.categoryId is None:
            category = self.categories.get(str(offer.categoryId), None)
        else:
            category = None

        discount = 0
        if offer.oldprice:
            price = float(offer.oldprice)
            discount = 1 - (float(offer.price)/price)
        else:
            price = offer.price

        if offer.vendor:
            manufacturer = self.add_manufacturer(offer.vendor)
        else:
            manufacturer = None

        product, created = Product.objects.get_or_create(
            name=offer.name,
            manufacturer=manufacturer,
            defaults={
                'category': category,
                'slug': slugify(offer.name),
                'description': offer.description,
                'price': price,
                'discount': discount,
                'articul': offer.vendorCode,
            })

        for param in offer.params:
            self.add_property(
                value=param['value'],
                property_type=self.add_property_type(name=param['name'], category=category),
                product=product
            )

        for picture in offer.pictures:
            self.add_image(picture, product)

        return product

    def add_manufacturer(self, name):
        """

        :param name: str
        :return: Manufacturer
        """
        manufacturer, created = Manufacturer.objects.get_or_create(name=name, defaults={'slug': slugify(name)})
        return manufacturer

    def add_property(self, value, property_type, product):
        """

        :param value: str or unicode
        :param property_type: PropertyType
        :param product: Product
        :return: Property
        """
        prop, created = Property.objects.get_or_create(
            property_type=property_type,
            product=product,
            value=value
        )
        return prop

    def add_property_type(self, name, category):
        """

        :param name: str
        :param category: Category
        :return: PropertyType
        """
        property_type, created = PropertyType.objects.get_or_create(name=name)
        if created and category:
            ptcr = PropertyTypeCategoryRelation(property_type=property_type, category=category, max_count=1)
            ptcr.save()
        return property_type

    def add_image(self, picture, product):
        """

        :param picture: str image's url
        :param product: Product
        :return:
        """
        if product.manufacturer:
            image_type_str = product.manufacturer.name
        else:
            image_type_str = getattr(settings, 'SHOP_DEFAULT_IMAGE_TYPE', 'Default image type')
        image_type = self.add_image_type(name=image_type_str, category=product.category)
        image, created = Image.objects.get_or_create(
            image=picture,
            product=product,
            defaults={
                'name': product.name,
                'image_type': image_type
            }
        )
        if not product.has_main_image():
            image.is_main = True
            image.save()


    def add_image_type(self, name, category):
        """

        :param name: str or unicode
        :param category: Category
        :return: ImageType
        """
        image_type, created = ImageType.objects.get_or_create(name=name)
        if created and category:
            itcr = ImageTypeCategoryRelation(image_type=image_type, category=category, max_count=1)
            itcr.save()
        return image_type



#~*~ coding: utf-8 ~*~
import os
import string
from django.conf import settings
from datetime import date
from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
from pytils.translit import slugify
import random
from virtenviro.shop.models import *

UPLOAD_PATH = getattr(settings, 'UPLOAD_PATH', 'upload')


def set_slug(model, src, length=60):
    slug = slugify(src)[0:length]
    try:
        obj = model.objects.get(slug=slug)
        slug = set_slug(model, slug, length)
    except model.DoesNotExist:
        return slug


def set_main_images():
    production = Product.objects.all()
    for product in production:
        if product.has_main_image():
            pass
        else:
            images = product.image_set.all()
            if images:
                image = images[0]
                image.is_main = True
                image.save()
            else:
                try:
                    print 'Product %s [%s] has no image' % (product.title, product.pk)
                except:
                    print 'Product RUS [%s] has no image' % (product.pk)


def set_any_image():
    production = Product.objects.all()
    i = 0
    for product in production:
        if not product.image_set.all():
            if not product.is_leaf_node():
                children = product.get_children()
                for child in children:
                    if child.has_main_image():
                        cimage = child.get_main_image()
                        image = Image()
                        image.image = cimage.image
                        image.title = product.title
                        image.product = product
                        image.image_type = cimage.image_type
                        image.is_main = True
                        image.save()
                        i = i + 1
                        break
    print 'I\'ve set %s images' % i


def ucode(str, encoding="utf-8", errors="ignore"):
    return unicode(str, encoding=encoding, errors=errors)


def handle_uploads(request, keys):
    saved = {}
    upload_full_path = os.path.join(settings.STATIC_ROOT, 'upload')

    # check and make upload_full_path
    if not os.path.exists(upload_full_path):
        os.makedirs(upload_full_path)

    # read request.FILES and write files
    for key in keys:
        if key in request.FILES:
            upload = request.FILES[key]
            while os.path.exists(os.path.join(upload_full_path, upload.name)):
                upload.name = '_' + upload.name
            dest = open(os.path.join(upload_full_path, upload.name), 'wb')
            for chunk in upload.chunks():
                dest.write(chunk)
            dest.close()
            saved[key] = os.path.join(upload_full_path, upload.name)
    # returns {key1: path1, key2: path2, ...}
    return saved


def id_generator(size=6, chars=string.ascii_uppercase + string.ascii_lowercase + string.digits):
    return ''.join(random.choice(chars) for _ in range(size))


def paginate(objects, page=1, count=10):
    paginator = Paginator(objects, count)
    try:
        pages = paginator.page(page)
    except PageNotAnInteger:
        pages = paginator.page(1)
    except EmptyPage:
        pages = paginator.page(paginator.num_pages)

    return pages


def sha256(str):
    import hashlib
    m = hashlib.sha256()
    m.update(str)
    return m.digest()


'''
from importlib import import_module
module_ = import_module('path.to.module')
module_.call_some_method()
module_.variable
'''



# ~*~ coding: utf-8 ~*~
import os
from django.db import models
from django.utils.translation import ugettext_lazy as _
from mptt.models import MPTTModel, TreeForeignKey
from pytils.translit import slugify
from django.conf import settings
from virtenviro.utils import set_slug, sha256, id_generator
from managers import *

MEDIA_ROOT = getattr(settings, 'MEDIA_ROOT', getattr(settings, 'STATIC_ROOT'))


class Mark(MPTTModel):
    name = models.CharField(max_length=255, verbose_name=_('Name'))
    slug = models.CharField(max_length=60, verbose_name=_('Slug'), null=True, blank=True)
    parent = TreeForeignKey('self', verbose_name=_('Parent'), related_name='subcategories', null=True, blank=True)
    description = models.TextField(verbose_name=_('Description'), null=True, blank=True)
    image = models.ImageField(upload_to=_(os.path.join(MEDIA_ROOT, 'img', 'auto_adv', 'category')), verbose_name=_('Image'), null=True, blank=True)

    # SERVICE FIELDS
    view_count = models.IntegerField(default=0, verbose_name=_('Count of views'), blank=True, null=True)

    # META FIELDS
    meta_title = models.CharField(max_length=250, verbose_name=_('Meta Title'), null=True, blank=True)
    meta_keywords = models.TextField(verbose_name=_('Meta Keywords'), null=True, blank=True)
    meta_description = models.TextField(verbose_name=_('Meta Description'), null=True, blank=True)

    def __unicode__(self):
        return self.name

    def clean(self):
        if not self.slug:
            self.slug = set_slug(Mark, self.name, length=60)

    def get_absolute_url(self):
        if self.parent is None:
            return '/%s/' % self.slug
        else:
            url = self.get_all_ancestors(self.parent, self.slug)
        return '%s' % url

    get_absolute_url.short_description = _('URL')

    def get_all_ancestors(self, parent, url=''):
        url = '%s/%s' % (parent.slug, url)
        if parent.parent:
            return self.get_all_ancestors(parent.parent, url)
        else:
            return '/%s/' % url

    class Meta:
        ordering = ['name']
        verbose_name = _('Category')
        verbose_name_plural = _('Categories')


class Model(models.Model):
    name = models.CharField(max_length=255, verbose_name=_('Name'))
    slug = models.CharField(max_length=60, verbose_name=_('Slug'), null=True, blank=True)
    mark = models.ForeignKey(Mark, verbose_name=_('Mark'), related_name='children', null=True, blank=True)
    description = models.TextField(verbose_name=_('Description'), null=True, blank=True)

    # SERVICE FIELDS
    view_count = models.IntegerField(default=0, verbose_name=_('Count of views'), blank=True, null=True)

    def __unicode__(self):
        return self.name

    def new_price(self):
        discount = self.discount/100
        price = self.price - self.price * discount
        return price

    def clean(self, *args, **kwargs):
        if not self.slug:
            self.slug = set_slug(Model, self.name, length=60)

        if not self.articul:
            self.articul = id_generator(size=15)
        '''
        if not self.unique_code:
            if self.manufacturer:
                manufacturer = self.manufacturer.name
            else:
                manufacturer = ''
            unique_code_string = '{}{}{}'.format(self.name, manufacturer, self.articul)
            self.unique_code = sha256(unique_code_string)
        '''

    def get_main_images(self):
        return self.image_set.all().filter(is_main=True)

    def get_main_image(self):
        main_images = self.image_set.all().filter(is_main=True)
        if not main_images:
            return None
        else:
            return main_images[0]

    def has_main_image(self):
        if self.image_set.all().filter(is_main=True):
            return True
        else:
            return False
        return False

    def filter_group(self):
        return self.filter(is_group=True)

    def filter_parent_group(self):
        return self.filter(is_group=True, parent__isnull=True)

    def get_absolute_url(self):
        return '%s%s/' % (self.category.get_absolute_url(), self.slug)

    get_absolute_url.short_description = _('URL')

    class Meta:
        ordering = ['name']
        verbose_name = _('Model')
        verbose_name_plural = _('Models')


class Advert(models.Model):
    description = models.TextField(verbose_name=_('Description'), null=True, blank=True)
    price = models.FloatField(verbose_name=_('Price'), default=0.0)
    contacts = models.TextField(verbose_name=_('Contacts'), null=True, blank=True)
    created_datetime = models.DateTimeField(verbose_name=_('Creation datetime'))
    model = models.ForeignKey(Model, verbose_name=_('Model'))
    archive = models.BooleanField(default=False, verbose_name=_('In archive'))
    sold = models.BooleanField(default=False, verbose_name=_('Sold'))
    change_datetime = models.DateTimeField(verbose_name=_('Changing datetime'))
    user = models.ForeignKey(User, verbose_name=_('User'))

    # SERVICE FIELDS
    view_count = models.IntegerField(default=0, verbose_name=_('Count of views'), blank=True, null=True)
    identifier = models.CharField(max_length=255, verbose_name=_('Identifier for importing'))

    objects = AdvertManager()

    def get_absolute_url(self):
        return '%s%s/' % (self.model.get_absolute_url(), self.pk)

    class Meta:
        ordering = ['-created_datetime', '-change_datetime']
        verbose_name = _('Model')
        verbose_name_plural = _('Models')


class PropertyType(models.Model):
    DATA_TYPES = (
        (-1, _('Integer'),),
        (-2, _('Float')),
        (-3, _('String')),
        (-4, _('Text')),
        (-5, _('Boolean')),
        (-6, _('Html')),
    )
    name = models.CharField(max_length=255, verbose_name=_('Name'))
    data_type = models.IntegerField(verbose_name=_('Data type'), default=-1, choices=DATA_TYPES)

    def __unicode__(self):
        return '%s [%s]' % (self.name, self.pk)

    class Meta:
        ordering = ['name']
        verbose_name = _('Properties type')
        verbose_name_plural = _('Properties Types')


class Property(models.Model):
    property_type = models.ForeignKey(PropertyType)
    value = models.TextField(verbose_name=_('Value'))
    advert = models.ForeignKey(Advert, verbose_name=_('Advert'))

    objects = PropertyManager()

    def __unicode__(self):
        return '%s: %s' % (self.property_type.name, self.value)

    class Meta:
        ordering = ['property_type__name', 'value']
        verbose_name = _('Property')
        verbose_name_plural = _('Properties')


class Image(models.Model):
    image = FileBrowseField("Image", max_length=200, directory=os.path.join(MEDIA_ROOT, 'img', 'auto_adv'),
                            blank=True, null=True)
    name = models.CharField(max_length=255, verbose_name=_('Name'), blank=True, null=True)
    advert = models.ForeignKey(Advert, verbose_name=_('Advert'))
    is_main = models.BooleanField(default=False, verbose_name=_('Is Main'))

    def __unicode__(self):
        return '%s [%s%s]' % (self.name, MEDIA_ROOT, self.image)

    class Meta:
        ordering = ['image_type', 'name']
        verbose_name = _('Image')
        verbose_name_plural = _('Images')


# ~*~ coding: utf-8 ~*~
import os
import urllib2
import datetime

from lxml import etree
from django.conf import settings

from virtenviro.shop.models import Currency


def update_currency():
    current_date = datetime.datetime.now()
    url = 'http://www.cbr.ru/scripts/XML_daily.asp?date_req=%s/%s/%s' % (current_date.day,
                                                                         current_date.month, current_date.year)
    xml_file = os.path.join(settings.MEDIA_ROOT, 'Valute%s.%s.%s.xml' % (current_date.day,
                                                                         current_date.month, current_date.year))
    f = open(xml_file, 'wb')
    opener = urllib2.build_opener()
    opener.addheaders = [('User-Agent',
                          'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36'
                          ' (KHTML, like Gecko) Chrome/34.0.1847.137 Safari/537.36')]
    response = opener.open(url)
    data = response.read()
    opener.close()
    f.write(data)
    f.close()
    '''
    Fields in xml
    Valute
        NumCode
        CharCode
        Nominal
        Name
        Value
    '''
    parser = etree.XMLParser(remove_blank_text=True)
    tree = etree.parse(xml_file, parser)
    for valute in tree.iterfind('.//Valute'):
        name = valute.find('Name').text
        try:
            currency = Currency.objects.get(name=name)
        except Currency.DoesNotExist:
            continue
        currency.char_code = valute.find('CharCode').text
        currency.num_code = int(valute.find('NumCode').text)
        currency.value = float(valute.find('Value').text)
        currency.nominal = float(valute.find('Nominal').text)
        currency.save()




# ~*~ coding: utf-8 ~*~
__author__ = 'Kamo Petrosyan'
from django.core.management.base import BaseCommand, CommandError
from lxml import etree

from virtenviro.content.models import Page, AdditionalField, FieldValue, Template


def create_page(title, slug, content, template, is_home=False, intro='',
                parent=None, seo_title=None, seo_keywords=None, seo_description=None):
    """

    :rtype : Page
    """
    try:
        return Page.objects.get(title=title, slug=slug)
    except Page.DoesNotExist:
        page = Page()
        page.title = title
        page.slug = slug
        page.content = content
        page.is_home = is_home
        page.intro = intro
        page.template = template
        page.parent = parent
        page.seo_title = seo_title
        page.seo_keywords = seo_keywords
        page.seo_description = seo_description

        page.save()
        return page


def get_or_create_parent(title, slug, group_template):
    if not title:
        return None

    try:
        parent = Page.objects.get(title=title, slug=slug)
    except Page.DoesNotExist:
        parent = Page()
    parent.title = title
    parent.slug = slug
    parent.is_home = False
    parent.template = group_template
    parent.save()

    return parent


def get_or_create_additional_field(field_name, field_type, render):
    """

    :param field_name: string
    :param field_type: string
    :param render: boolean, string or integer
    :return: AdditionalField
    """

    if isinstance(render, basestring):
        if render == 'False':
            render = False
        else:
            render = True
    else:
        render = bool(render)

    try:
        return AdditionalField.objects.get(name=field_name)
    except AdditionalField.DoesNotExist:
        try:
            render = bool(render)
        except ValueError:
            raise CommandError('Invalid option "render" in file.')
        field = AdditionalField()
        field.name = field_name
        field.field_type = field_type
        field.render = render
        field.save()
        return field


class Command(BaseCommand):
    args = '<xml_file group_template_id page_template_id>'
    help = 'Imports xml file as pages in content application'

    def handle(self, *args, **options):
        if len(args) < 3:
            raise CommandError('Command import_content takes 3 arguments. {} given'.format(len(args)))
        parser = etree.XMLParser(remove_blank_text=True)
        try:
            tree = etree.parse(args[0], parser)
        except IOError:
            raise CommandError('Error reading file \'{0}\': failed to load external entity "{0}"'.format(args[0]))

        try:
            group_template = Template.objects.get(pk=int(args[1]))
        except Template.DoesNotExist:
            raise CommandError('Template {} Does not exist'.format(args[1]))
        except ValueError:
            raise CommandError('Argument 1 is not integer value ')
        try:
            page_template = Template.objects.get(pk=int(args[2]))
        except Template.DoesNotExist:
            raise CommandError('Template {} Does not exist'.format(args[2]))
        except ValueError:
            raise CommandError('Argument 2 is not integer value ')

        for page_xml in tree.iterfind('.//PAGE'):
            title = page_xml.find('TITLE').text
            slug = page_xml.find('SLUG').text
            is_home = False
            intro = page_xml.find('INTRO').text
            content = page_xml.find('CONTENT').text
            template = page_template
            seo_keywords = page_xml.find('SEO_KEYWORDS').text
            seo_description = page_xml.find('SEO_DESCRIPTION').text
            parent_slug = page_xml.find('PARENT_SLUG').text
            parent_title = page_xml.find('PARENT_TITLE').text

            page = create_page(title=title, slug=slug, content=content, template=template, is_home=is_home,
                               intro=intro, parent=get_or_create_parent(title=parent_title, slug=parent_slug,
                                                                        group_template=group_template), seo_title=None,
                               seo_keywords=seo_keywords,
                               seo_description=seo_description)

            for field_xml in page_xml.iterfind('FIELD'):
                field_name = field_xml.find('NAME').text
                field_type = field_xml.find('FIELD_TYPE').text
                field_value = field_xml.find('VALUE').text
                field_render = field_xml.find('RENDER').text

                additional_field = get_or_create_additional_field(field_name, field_type, field_render)
                # todo: if additional field is not in page_template's additional fields list, then add it

                page_field_value = FieldValue()
                page_field_value.page = page
                page_field_value.additional_field = additional_field
                page_field_value.value = field_value
                page_field_value.save()




from distutils.core import setup
from setuptools import find_packages, setup

EXCLUDE_FROM_PACKAGES = []


def get_version(major=0, minor=0, build=0):
    return '%s.%s.%s' % (major, minor, build)


setup(
    name='virtenviro',
    version=get_version(
        major=0,
        minor=7,
        build=8
    ),
    packages=find_packages(exclude=EXCLUDE_FROM_PACKAGES),
    include_package_data=True,
    url='http://www.virtenviro.org/',
    license='GPL3',
    author='Kamo Petrosyan',
    author_email='kamo@haikson.com',
    description='Open source content management system (CMS) based on the django framework.',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Internet :: WWW/HTTP :: WSGI',
        'Topic :: Software Development',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    install_requires=[
        'django==1.8.8',
        'django-mptt',
        'django-filebrowser-no-grappelli',
        'lxml',
        'Pillow',
        'pytils',
        'sorl-thumbnail',
        'django-datetime-widget',
    ]
)



# ~*~ coding: utf-8 ~*~
__author__ = 'Kamo Petrosyan'
from django import template
from django.template import loader, Context
from django.db import  models
from virtenviro.content.models import Snippet, Page, AdditionalField
from virtenviro.shop.models import *
from virtenviro.utils import *
register = template.Library()

'''
@register.assignment_tag(takes_context=True)
def get_content_ml(context, page, lang):
    content = page.get_content(language=lang)
    return content
'''


@register.assignment_tag
def get_product(product_pk):
    try:
        return Product.objects.get(pk=product_pk)
    except Product.DoesNotExist:
        return None

@register.assignment_tag
def get_order(order_pk):
    try:
        return Order.objects.get(pk=order_pk)
    except Order.DoesNotExist:
        return None


@register.assignment_tag
def all_manufacturers():
    return Manufacturer.objects.all()


@register.assignment_tag()
def all_categories(parent=None):
    if parent is None:
        return Category.objects.filter(parent__isnull=True)
    else:
        return Category.objects.filter(parent=parent)


@register.assignment_tag
def random_products(manufacturer=None, count=12):
    products = Product.objects.all()
    if not manufacturer is None:
        products = products.filter(manufacturer=manufacturer)

    return products.order_by('?')[0:count]


@register.assignment_tag
def get_properties_grouped(property_type=None):
    return Property.objects.grouped(property_type=property_type).extra(
        select={
            'intval': 'CAST(substring(value FROM \'^[0-9]+\') AS INTEGER)'},
        order_by=['intval', 'value'])


@register.assignment_tag
def get_property_image(property_value, property_type):
    try:
        pr = Property.objects.filter(value=property_value, property_type=property_type)[0]
        ps = Product.objects.filter(property__value=pr.value, property__property_type=pr.property_type)
        return Image.objects.filter(is_main=True, product__in=ps)[0]
    except:
        return None

@register.assignment_tag
def get_property(product, property_type):
    try:
        return Property.objects.get(product=product, property_type=property_type)
    except Property.DoesNotExist:
        return None

@register.assignment_tag
def most_viewed(count=None):
    if count is None:
        count = getattr(settings, 'SHOP_MOST_VIEWED_COUNT', 10)

    production = Product.objects.all().order_by('-view_count', 'ordering', 'name')[0: count]
    return production

@register.assignment_tag
def discounted(count=None):
    production = Product.objects.filter(discount__gt=0).order_by('?')
    if not count is None:
        production = production[0: count]
    return production


@register.assignment_tag
def get_sellers():
    return Seller.objects.all().order_by('ordering')


#~*~ coding: utf-8 ~*~
import os
from django.core.exceptions import ValidationError
from django.db import models
from django.utils.translation import ugettext_lazy as _
from pytils.translit import slugify
from mptt.models import MPTTModel, TreeForeignKey
from django.contrib.auth.models import User
import datetime
from django.utils import timezone
from django.conf import settings
from virtenviro.abstract_models import AbstractSeo, AbstractContent,\
    AbstractContentMultilingual
from virtenviro.content.managers import PageManager

LANGUAGE_CODE = getattr(settings, 'LANGUAGE_CODE', 'ru')
LANGUAGES = getattr(settings, 'LANGUAGES', ('ru',))


class Page(MPTTModel):
    title = models.CharField(max_length=250, verbose_name=_('Title'))
    slug = models.CharField(max_length=250, blank=True, verbose_name=_('Slug'), unique=True)
    is_home = models.BooleanField(default=False, verbose_name=_('Is home page'))
    is_category = models.BooleanField(default=False, verbose_name=_('Is category'))
    template = models.ForeignKey('Template', verbose_name=_('Template'))
    parent = TreeForeignKey('self', blank=True, null=True, related_name='child_set', verbose_name=_('Parent'))

    miniature = models.ImageField(upload_to=os.path.join(settings.MEDIA_ROOT, 'img', 'miniature'),
                                  verbose_name=_('Miniature'), null=True, blank=True)

    # SERVICE FIELDS
    ordering = models.IntegerField(default=999999, verbose_name=_('Ordering'))
    login_required = models.BooleanField(default=False, verbose_name=_('Login required'))
    published = models.BooleanField(default=False, verbose_name=_('Published'))
    pub_datetime = models.DateTimeField(default=timezone.now, verbose_name=_('Created datetime'))
    last_modified = models.DateTimeField(auto_now=True, verbose_name=_('Last modified datetime'))

    author = models.ForeignKey(User, verbose_name=_('Author'), related_name='created_pages', blank=True, null=True)
    last_modified_by = models.ForeignKey(User, verbose_name=_('Corrector'), blank=True, null=True,
                                         related_name='modified_pages')

    def get_content(self, language=LANGUAGE_CODE):
        contents = self.contents.filter(language=language)
        if contents:
            return contents[0]
        return None

    def get_contents(self):
        return self.contents.all()

    def get_languages(self):
        languages = []
        for c in self.get_contents():
            languages.append(c.language)
        return languages

    def __unicode__(self):
        return self.title

    def get_absolute_url(self):
        if self.is_home:
            return '/'
        if self.parent is None:
            return '/%s/' % self.slug
        url = self.get_all_ancestors(self.parent, self.slug)
        return '%s' % url

    get_absolute_url.short_description = _('URL')

    def get_all_ancestors(self, parent, url=''):
        url = '%s/%s' % (parent.slug, url)
        if parent.parent:
            return self.get_all_ancestors(parent.parent, url)
        else:
            return '/%s/' % url

    def clean(self):
        # slugify
        if not self.slug:
            slug = self.title
        else:
            slug = self.slug
        self.slug = slugify(slug)
        if Page.objects.filter(slug=self.slug, parent=None).exclude(id=self.id).exists() and self.parent is None:
            raise ValidationError(
                _('Record with this slug already exists')
            )

    def save(self, *args, **kwargs):
        if self.is_home is True:
            try:
                page = Page.objects.get(is_home=True)
                page.is_home = False
                page.save()
            except Page.DoesNotExist:
                self.is_home = True
        return super(Page, self).save(*args, **kwargs)

    class Meta:
        ordering = ['ordering', '-pub_datetime', 'title']
        verbose_name = _('Page')
        verbose_name_plural = _('Pages')
        unique_together = ('parent', 'slug', )


class Content(models.Model):
    title = models.CharField(max_length=250, verbose_name=_('Title'))
    h1 = models.CharField(max_length=250, verbose_name=_('H1 tag'), null=True, blank=True)
    intro = models.TextField(verbose_name=_('Intro'), null=True, blank=True)
    content = models.TextField(verbose_name=_('Content'), null=True, blank=True)
    template = models.ForeignKey('content.Template', verbose_name=_('Template'), null=True, blank=True)
    language = models.CharField(max_length=10, verbose_name=_('Language'), choices=LANGUAGES, default=LANGUAGE_CODE)

    parent = models.ForeignKey(Page, blank=True, null=True, related_name='contents', verbose_name=_('Parent'))

    # META FIELDS
    meta_title = models.CharField(max_length=250, verbose_name=_('Meta Title'), null=True, blank=True)
    meta_keywords = models.TextField(verbose_name=_('Meta Keywords'), null=True, blank=True)
    meta_description = models.TextField(verbose_name=_('Meta Description'), null=True, blank=True)

    # SERVICE FIELDS
    published = models.BooleanField(default=False, verbose_name=_('Published'))
    pub_datetime = models.DateTimeField(default=timezone.now, verbose_name=_('Created datetime'))
    last_modified = models.DateTimeField(auto_now=True, verbose_name=_('Last modified datetime'))

    author = models.ForeignKey(User, verbose_name=_('Author'), related_name='created_contents', blank=True, null=True)
    last_modified_by = models.ForeignKey(User, verbose_name=_('Corrector'), blank=True, null=True,
                                         related_name='modified_contents')

    def get_template(self):
        if not self.template is None:
            return self.template
        else:
            return self.parent.template

    def __unicode__(self):
        return self.title

    def get_absolute_url(self):
        return self.parent.get_absolute_url()

    get_absolute_url.short_description = _('URL')


class Template(MPTTModel):
    title = models.CharField(max_length=255, verbose_name=_('Title'), null=False, blank=False)
    filename = models.CharField(max_length=255, verbose_name=_('Filename'))
    parent = TreeForeignKey('self', verbose_name=_('Parent'), null=True, blank=True)
    
    def __unicode__(self):
        return self.title
    
    class Meta:
        ordering = ['title']
        verbose_name = _('Template')
        verbose_name_plural = _('Templates')

        
class Snippet(models.Model):
    name = models.CharField(max_length=255, verbose_name=_('Name'), unique=True)
    code = models.TextField(verbose_name=_('Code'), null=True, blank=True)
    render = models.BooleanField(default=False, verbose_name=_('Render'))
    template = models.CharField(max_length=255, verbose_name=_('Template'), null=True, blank=True)

    def __unicode__(self):
        return self.name

    class Meta:
        ordering = ['name']
        verbose_name = _('Snippet')
        verbose_name_plural = _('Snippets')


class AdditionalField(models.Model):
    FIELD_TYPES = (
        ('char', _('Char field')),
        ('text', _('Text field')),
        ('int', _('Integer field')),
        ('float', _('Float field')),
        ('image', _('Image field')),
    )

    name = models.CharField(max_length=255, verbose_name=_('Name'), unique=True)
    field_type = models.CharField(max_length=20, verbose_name=_('Field\'s data type'), choices=FIELD_TYPES)
    template = models.ManyToManyField(Template, verbose_name=_('Templates'), related_name='additional_fields')
    render = models.BooleanField(default=False, verbose_name=_('Render field\'s value'))

    def __unicode__(self):
        return self.name

    class Meta:
        ordering = ['name']
        verbose_name = _('Additional field')
        verbose_name_plural = _('Additional fields')


class FieldValue(models.Model):
    content = models.ForeignKey(Content, verbose_name=_('Content'))
    additional_field = models.ForeignKey(AdditionalField, verbose_name=_('Additional field'))
    value = models.TextField(verbose_name=_('Value'))

    def __unicode__(self):
        return '%s %s %s' % (self.additional_field.name, _('for'), self.page.title)

    class Meta:
        verbose_name = _('Additional field\'s value')
        verbose_name_plural = _('Additional field\'s values')


class Tag(models.Model):
    tag = models.CharField(max_length=200, verbose_name=_('Tag'))
    content = models.ManyToManyField(Content, verbose_name=_('Content'), related_name='tags')

    def __unicode__(self):
        return self.tag

    class Meta:
        ordering = ['tag', ]
        verbose_name = _('Tag')
        verbose_name_plural = _('Tags')

class Menu(models.Model):
    name = models.CharField(max_length=255, verbose_name=_('Name'))
    sys_name = models.CharField(max_length=255, verbose_name=_('System name'))
    page = models.ManyToManyField(Page, verbose_name=_('Page'), through='PageMenuRelationship')

    def __unicode__(self):
        return self.name

    class Meta:
        ordering = ['name']
        verbose_name = _('Menu')
        verbose_name_plural = _('Menus')


class PageMenuRelationship(models.Model):
    TARGETS = (
            ('_blank', '_blank'),
            ('_self', '_self'),
            ('_parent', '_parent'),
            ('_top', '_top'),
        )

    MENI_ITEM_TYPES = (
            ('page', u'Страница'),
            ('url', u'URL'),
            ('code', u'Код ссылки'),
        )

    page = models.ForeignKey(Page, null=True, blank=True)
    menu = models.ForeignKey(Menu)
    title = models.CharField(max_length=255, verbose_name=_('Title'), null=True, blank=True)
    url = models.URLField(null=True, blank=True)
    target = models.CharField(max_length=15, verbose_name=u'Target', choices=TARGETS, null=True, blank=True)
    code = models.TextField(verbose_name=u'Код ссылки', null=True, blank=True)
    menu_item_type = models.CharField(max_length=25, default=u'page', verbose_name=u'Тип элемента меню', choices=MENI_ITEM_TYPES)
    ordering = models.IntegerField(default=9999, verbose_name=_('Ordering'))

    def __unicode__(self):
        if self.menu and self.page:
            return '[%s] %s' % (self.menu.name, self.page.title)
        elif self.menu:
            return '[%s] %s' % (self.menu.name, self.pk)
        else:
            return '%s' % self.pk

    class Meta:
        ordering = ['menu', 'ordering']
        verbose_name = _('Page Menu Relationship')
        verbose_name_plural = _('Page Menu Relationships')



#~*~ coding: utf-8 ~*~
from django.contrib import admin
from virtenviro.registration.models import *


class UserProfileAdmin(admin.ModelAdmin):
    list_display = ('user', 'activation_code')

admin.site.register(UserProfile, UserProfileAdmin)


# ~*~ coding: utf-8 ~*~
__author__ = 'Kamo Petrosyan'
from django.apps import apps


'''
This is the best way to accomplish what you want to do:

from django.apps import apps

app = apps.get_app('my_application_name')
for model in get_models(app):
    # do something with the model

In this example, model is the actual model, so you can do plenty of things with it:

for model in apps.get_models(app):
    new_object = model() # Create an instance of that model
    model.objects.filter(...) # Query the objects of that model
    model._meta.db_table # Get the name of the model in the database
    model._meta.verbose_name # Get a verbose name of the model
    # ...
'''


def get_apps():
    """
    Returns a list of all installed modules that contain models.
    """
    return apps.get_apps()


def get_models():
    return apps.get_models